SPOOL .\Logs\02-Tablas.txt
PROMPT Generando tablas... 

-- Se eliminan las tablas existentes

DROP TABLE ESTADISTICO;
DROP TABLE HECHO;
DROP TABLE PRODUCTO;
DROP TABLE TIENDA;
DROP TABLE TIEMPO;
DROP TABLE REGION;
DROP TABLE CIUDAD;
DROP TABLE PAIS;
DROP TABLE MENSAJE;
DROP TABLE LOG_ACTIVIDAD;

/*----------------------------------------------------------------------------*/
/*                                    Log                                     */
/*----------------------------------------------------------------------------*/

CREATE TABLE     LOG_ACTIVIDAD   
(I_ENTRADA       INTEGER
,V_PROCEDIMIENTO VARCHAR2(50 CHAR)   CONSTRAINT NN_L_PROCEDIMIENTO NOT NULL
,V_ENTRADA       VARCHAR2(1000 CHAR) CONSTRAINT NN_L_ENTRADA       NOT NULL
,V_EJECUCION     VARCHAR2(250 CHAR)  CONSTRAINT NN_L_EJECUCION     NOT NULL
,F_ALTA          DATE                CONSTRAINT NN_L_ALTA          NOT NULL
,CONSTRAINT      PK_LOG_ACTIVIDAD 
                 PRIMARY KEY(I_ENTRADA));

COMMENT ON TABLE  LOG_ACTIVIDAD                 IS 'Registra la actividad en la base de datos';
COMMENT ON COLUMN LOG_ACTIVIDAD.I_ENTRADA       IS 'Cdigo de identificacin'; 
COMMENT ON COLUMN LOG_ACTIVIDAD.V_PROCEDIMIENTO IS 'Nombre del procedimiento'; 
COMMENT ON COLUMN LOG_ACTIVIDAD.V_ENTRADA       IS 'Parmetros de entrada'; 
COMMENT ON COLUMN LOG_ACTIVIDAD.V_EJECUCION     IS 'Resultado de la ejecucin';  
COMMENT ON COLUMN LOG_ACTIVIDAD.F_ALTA          IS 'Fecha de incorporacin a la tabla';

/*----------------------------------------------------------------------------*/
/*                             Pas                                           */
/*----------------------------------------------------------------------------*/

CREATE TABLE    PAIS
(V_PAIS         VARCHAR2(3 CHAR)
,V_NOMBRE       VARCHAR2(100 CHAR) CONSTRAINT NN_P_NOMBRE NOT NULL
,F_ALTA         DATE               CONSTRAINT NN_P_ALTA   NOT NULL
,F_MODIFICACION DATE
,F_ELIMINACION  DATE
,CONSTRAINT     PK_PAIS 
                PRIMARY KEY (V_PAIS)
,CONSTRAINT     CK_P_MODIFICACION
                CHECK (F_MODIFICACION >= F_ALTA)
,CONSTRAINT     CK_P_ELIMINACION
                CHECK (F_ELIMINACION >= F_ALTA));

-- Comentarios 

COMMENT ON TABLE  PAIS                IS 'Paises';
COMMENT ON COLUMN PAIS.V_PAIS         IS 'Cdigo de identificacin'; 
COMMENT ON COLUMN PAIS.V_NOMBRE       IS 'Nombre del pas'; 
COMMENT ON COLUMN PAIS.F_ALTA         IS 'Fecha de incorporacin a la tabla'; 
COMMENT ON COLUMN PAIS.F_MODIFICACION IS 'Fecha ltima modificacin'; 
COMMENT ON COLUMN PAIS.F_ELIMINACION  IS 'Fecha de desactivacin';  

/*----------------------------------------------------------------------------*/
/*                             Ciudad                                         */
/*----------------------------------------------------------------------------*/

CREATE TABLE    CIUDAD
(I_CIUDAD       INTEGER
,V_NOMBRE       VARCHAR2(100) CONSTRAINT NN_C_NOMBRE NOT NULL
,V_PAIS      	VARCHAR2(3)   CONSTRAINT NN_C_PAIS   NOT NULL    
,F_ALTA         DATE          CONSTRAINT NN_C_ALTA   NOT NULL
,F_MODIFICACION DATE
,F_ELIMINACION  DATE
,CONSTRAINT     PK_CIUDAD 
                PRIMARY KEY (I_CIUDAD)
,CONSTRAINT     FK_CIUDAD_PAIS
                FOREIGN KEY (V_PAIS) REFERENCES PAIS(V_PAIS)
,CONSTRAINT     CK_C_MODIFICACION
                CHECK (F_MODIFICACION >= F_ALTA)
,CONSTRAINT     CK_C_ELIMINACION
                CHECK (F_ELIMINACION >= F_ALTA));


-- Comentarios 

COMMENT ON TABLE  CIUDAD                IS 'Ciudades';
COMMENT ON COLUMN CIUDAD.I_CIUDAD       IS 'Cdigo de identificacin'; 
COMMENT ON COLUMN CIUDAD.V_NOMBRE       IS 'Nombre de la ciudad'; 
COMMENT ON COLUMN CIUDAD.V_PAIS         IS 'Nombre del pas';
COMMENT ON COLUMN CIUDAD.F_ALTA         IS 'Fecha de incorporacin a la tabla'; 
COMMENT ON COLUMN CIUDAD.F_MODIFICACION IS 'Fecha ltima modificacin'; 
COMMENT ON COLUMN CIUDAD.F_ELIMINACION  IS 'Fecha de desactivacin';  

/*----------------------------------------------------------------------------*/
/*                             Regin                                         */
/*----------------------------------------------------------------------------*/

CREATE TABLE    REGION
(I_REGION       INTEGER
,V_NOMBRE       VARCHAR2(100) CONSTRAINT NN_R_NOMBRE NOT NULL
,V_PAIS      	VARCHAR2(3)   CONSTRAINT NN_R_PAIS   NOT NULL    
,F_ALTA         DATE          CONSTRAINT NN_R_ALTA   NOT NULL
,F_MODIFICACION DATE
,F_ELIMINACION  DATE
,CONSTRAINT     PK_REGION 
                PRIMARY KEY (I_REGION)
,CONSTRAINT     FK_REGION_PAIS 
                FOREIGN KEY (V_PAIS) REFERENCES PAIS(V_PAIS)
,CONSTRAINT     CK_R_MODIFICACION
                CHECK (F_MODIFICACION >= F_ALTA)
,CONSTRAINT     CK_R_ELIMINACION
                CHECK (F_ELIMINACION >= F_ALTA));

-- Comentarios 

COMMENT ON TABLE  REGION                IS 'Regiones';
COMMENT ON COLUMN REGION.I_REGION       IS 'Cdigo de identificacin'; 
COMMENT ON COLUMN REGION.V_NOMBRE       IS 'Nombre de la regin'; 
COMMENT ON COLUMN REGION.V_PAIS         IS 'Nombre del pas';
COMMENT ON COLUMN REGION.F_ALTA         IS 'Fecha de incorporacin a la tabla'; 
COMMENT ON COLUMN REGION.F_MODIFICACION IS 'Fecha ltima modificacin'; 
COMMENT ON COLUMN REGION.F_ELIMINACION  IS 'Fecha de desactivacin';  

/*----------------------------------------------------------------------------*/
/*                             Tienda                                         */
/*----------------------------------------------------------------------------*/

CREATE TABLE    TIENDA
(I_TIENDA       INTEGER
,V_NOMBRE       VARCHAR2(250 CHAR) CONSTRAINT NN_T_NOMBRE       NOT NULL
,I_CIUDAD       INTEGER            CONSTRAINT NN_T_CIUDAD       NOT NULL
,I_REGION		INTEGER            CONSTRAINT NN_T_REGION       NOT NULL    
,V_EMAIL        VARCHAR2(250 CHAR) CONSTRAINT NN_T_EMAIL        NOT NULL
,N_TRABAJADORES NUMBER(5)          CONSTRAINT NN_T_TRABAJADORES NOT NULL     
,V_FRANQUICIA   VARCHAR2(1 CHAR)   CONSTRAINT NN_T_FRANQUICIA   NOT NULL
,V_VIRTUAL      VARCHAR2(1 CHAR)   CONSTRAINT NN_T_VIRTUAL      NOT NULL
,F_ALTA         DATE               CONSTRAINT NN_T_ALTA         NOT NULL
,F_MODIFICACION DATE
,F_ELIMINACION  DATE
,CONSTRAINT     PK_TIENDA 
                PRIMARY KEY (I_TIENDA)
,CONSTRAINT     FK_TIENDA_CIUDAD 
                FOREIGN KEY (I_CIUDAD) REFERENCES CIUDAD(I_CIUDAD)
,CONSTRAINT     FK_TIENDA_REGION 
                FOREIGN KEY (I_REGION) REFERENCES REGION(I_REGION)
,CONSTRAINT     CK_T_TRABAJADORES 
                CHECK (N_TRABAJADORES > 0)
,CONSTRAINT     CK_T_FRANQUICIA 
                CHECK (V_FRANQUICIA IN ('S','N'))
,CONSTRAINT     CK_T_VIRTUAL 
                CHECK (V_VIRTUAL IN ('S','N'))
,CONSTRAINT     UQ_T_NOMBRE 
                UNIQUE (V_NOMBRE)
,CONSTRAINT     CK_T_MODIFICACION
                CHECK (F_MODIFICACION >= F_ALTA)
,CONSTRAINT     CK_T_ELIMINACION
                CHECK (F_ELIMINACION >= F_ALTA));

-- Comentarios 

COMMENT ON TABLE  TIENDA                IS 'Tiendas';
COMMENT ON COLUMN TIENDA.I_TIENDA       IS 'Cdigo de identificacin'; 
COMMENT ON COLUMN TIENDA.V_NOMBRE       IS 'Nombre de la tienda';
COMMENT ON COLUMN TIENDA.I_CIUDAD       IS 'Cdigo de la ciudad en la que est ubicada'; 
COMMENT ON COLUMN TIENDA.I_REGION       IS 'Cdigo de la comunidad autonoma a la que pertenece';
COMMENT ON COLUMN TIENDA.V_EMAIL        IS 'E-mail del gerente';
COMMENT ON COLUMN TIENDA.N_TRABAJADORES IS 'Nmero de trabajadores';
COMMENT ON COLUMN TIENDA.V_FRANQUICIA   IS 'Indica si es una franquicia';
COMMENT ON COLUMN TIENDA.V_VIRTUAL      IS 'Indica si se trata de una tienda virtual';
COMMENT ON COLUMN TIENDA.F_ALTA         IS 'Fecha de incorporacin a la tabla'; 
COMMENT ON COLUMN TIENDA.F_MODIFICACION IS 'Fecha ltima modificacin'; 
COMMENT ON COLUMN TIENDA.F_ELIMINACION  IS 'Fecha de desactivacin';  

/*----------------------------------------------------------------------------*/
/*                      Productos                                             */
/*----------------------------------------------------------------------------*/

CREATE TABLE     PRODUCTO
(N_PRODUCTO      NUMBER(13)
,V_DESCRIPCION   VARCHAR2(50 CHAR) CONSTRAINT NN_PR_DESCRIPCION   NOT NULL
,F_INCORPORACION DATE              CONSTRAINT NN_PR_INCORPORACION NOT NULL
,F_ALTA          DATE              CONSTRAINT NN_PR_ALTA          NOT NULL
,F_MODIFICACION  DATE
,F_ELIMINACION   DATE
,CONSTRAINT      PK_PRODUCTO 
                 PRIMARY KEY (N_PRODUCTO)
,CONSTRAINT      CK_PR_MODIFICACION
                 CHECK (F_MODIFICACION >= F_ALTA)
,CONSTRAINT      CK_PR_ELIMINACION
                 CHECK (F_ELIMINACION >= F_ALTA));

-- Comentarios 

COMMENT ON TABLE  PRODUCTO                 IS 'Productos pertenecientes al catalogo';
COMMENT ON COLUMN PRODUCTO.N_PRODUCTO      IS 'Cdigo de identificin';
COMMENT ON COLUMN PRODUCTO.V_DESCRIPCION   IS 'Descripcin';
COMMENT ON COLUMN PRODUCTO.F_INCORPORACION IS 'Fecha en la que se incorpora al catlogo';
COMMENT ON COLUMN PRODUCTO.F_ALTA          IS 'Fecha de incorporacin a la tabla';
COMMENT ON COLUMN PRODUCTO.F_MODIFICACION  IS 'Fecha ltima modificacin';
COMMENT ON COLUMN PRODUCTO.F_ELIMINACION   IS 'Fecha de desactivacin'; 

/*----------------------------------------------------------------------------*/
/*                      Tiempo                                                */
/*----------------------------------------------------------------------------*/

CREATE TABLE    TIEMPO
(I_TIEMPO       INTEGER
,F_FECHA	    DATE      CONSTRAINT NN_TI_FECHA      NOT NULL
,N_ANYO         NUMBER(4) CONSTRAINT NN_TI_ANYO       NOT NULL
,N_MES          NUMBER(2) CONSTRAINT NN_TI_MES        NOT NULL
,N_DIA          NUMBER(2) CONSTRAINT NN_TI_DIA        NOT NULL
,N_TRIMESTRE    NUMBER(1) CONSTRAINT NN_TI_TRIMESTRE  NOT NULL
,N_SEMANA       NUMBER(2) CONSTRAINT NN_TI_SEMANA     NOT NULL
,N_DIA_SEMANA	NUMBER(1) CONSTRAINT NN_TI_DIA_SEMANA NOT NULL
,F_ALTA         DATE CONSTRAINT NN_TI_ALTA NOT NULL
,F_MODIFICACION DATE
,F_ELIMINACION  DATE
,CONSTRAINT     PK_TIEMPO 
                PRIMARY KEY (I_TIEMPO)
,CONSTRAINT     CK_TI_MODIFICACION
                CHECK (F_MODIFICACION >= F_ALTA)
,CONSTRAINT     CK_TI_ELIMINACION
                CHECK (F_ELIMINACION >= F_ALTA));

-- Comentarios 

COMMENT ON TABLE  TIEMPO                IS 'Fechas en las que se realizaron las ventas';
COMMENT ON COLUMN TIEMPO.I_TIEMPO       IS 'Cdigo de identificin';
COMMENT ON COLUMN TIEMPO.F_FECHA        IS 'Fecha en la que se efectu la venta';
COMMENT ON COLUMN TIEMPO.N_ANYO         IS 'Ao en el que se efectu la venta';
COMMENT ON COLUMN TIEMPO.N_MES          IS 'Mes en el que se efectu la venta';
COMMENT ON COLUMN TIEMPO.N_DIA          IS 'Da en el que se efectu la venta';
COMMENT ON COLUMN TIEMPO.N_TRIMESTRE    IS 'Trimestre en el que se efectu la venta';
COMMENT ON COLUMN TIEMPO.N_SEMANA       IS 'Semana en la que se efectu la venta';
COMMENT ON COLUMN TIEMPO.N_DIA_SEMANA   IS 'Da de la semana en el que se efectu la venta';
COMMENT ON COLUMN TIEMPO.F_ALTA         IS 'Fecha de incorporacin a la tabla';
COMMENT ON COLUMN TIEMPO.F_MODIFICACION IS 'Fecha ltima modificacin';
COMMENT ON COLUMN TIEMPO.F_ELIMINACION  IS 'Fecha de desactivacin'; 

/*----------------------------------------------------------------------------*/
/*                      Hechos                                                */
/*----------------------------------------------------------------------------*/

CREATE TABLE       HECHO
(I_TIENDA          INTEGER
,N_PRODUCTO        NUMBER(13) 
,I_TIEMPO          INTEGER 
,N_HORA            NUMBER(2) 
,I_CANTIDAD_VENTAS INTEGER      CONSTRAINT NN_H_CANTIDAD_VENTAS NOT NULL
,N_PRECIO_BRUTO    NUMBER(12,3) CONSTRAINT NN_H_PRECIO_BRUTO    NOT NULL
,N_BENEFICIO_NETO  NUMBER(12,3) CONSTRAINT NN_H_PRECIO_NETO     NOT NULL
,F_ALTA            DATE         CONSTRAINT NN_H_ALTA            NOT NULL
,F_MODIFICACION    DATE
,CONSTRAINT        PK_HECHO 
                   PRIMARY KEY (I_TIENDA, N_PRODUCTO, I_TIEMPO, N_HORA)
,CONSTRAINT        FK_HECHO_TIENDA 
                   FOREIGN KEY (I_TIENDA)   REFERENCES TIENDA(I_TIENDA)
,CONSTRAINT        FK_HECHO_PRODUCTO 
                   FOREIGN KEY (N_PRODUCTO) REFERENCES PRODUCTO(N_PRODUCTO)
,CONSTRAINT        FK_HECHO_TIEMPO 
                   FOREIGN KEY (I_TIEMPO)   REFERENCES TIEMPO(I_TIEMPO));
-- ,CONSTRAINT        CK_H_MODIFICACION
--                   CHECK (F_MODIFICACION >= F_ALTA));

-- Comentarios 

COMMENT ON TABLE  HECHO                   IS 'Informacin de las ventas realizadas cada da';
COMMENT ON COLUMN HECHO.I_TIENDA          IS 'Cdigo de identificin de la tienda';
COMMENT ON COLUMN HECHO.N_PRODUCTO        IS 'Cdigo de identificacin del producto';
COMMENT ON COLUMN HECHO.I_TIEMPO          IS 'Cdigo de identificacin de la fecha de venta';
COMMENT ON COLUMN HECHO.N_HORA            IS 'Hora en la que se realiz la venta';
COMMENT ON COLUMN HECHO.I_CANTIDAD_VENTAS IS 'Cantidad total del producto vendida durante el da/hora';
COMMENT ON COLUMN HECHO.N_PRECIO_BRUTO    IS 'Precio bruto total de los productos vendidos durante el da/hora';
COMMENT ON COLUMN HECHO.N_BENEFICIO_NETO  IS 'Beneficio neto total de los productos vendidos durante el da/hora';
COMMENT ON COLUMN HECHO.F_ALTA            IS 'Fecha de incorporacin a la tabla';
COMMENT ON COLUMN HECHO.F_MODIFICACION    IS 'Fecha ltima modificacin';

/*----------------------------------------------------------------------------*/
/*                      Mdulo estadstico                                    */
/*----------------------------------------------------------------------------*/

CREATE TABLE           ESTADISTICO
(N_ANYO                NUMBER(4)
,N_BNETO_CADENA        NUMBER
,I_TIENDA              INTEGER
,N_BNETO_TIENDA        NUMBER 
,N_PRODUCTO            NUMBER(13)
,I_PRODUCTO_UNIDADES   INTEGER
,N_HORA_MAS            NUMBER(2)
,I_HORA_MAS_UNIDADES   INTEGER
,N_HORA_MENOS          NUMBER(2)
,I_HORA_MENOS_UNIDADES INTEGER
,N_DIA_MAS             NUMBER(2)
,I_DIA_MAS_UNIDADES    INTEGER
,N_DIA_MENOS           NUMBER(2)
,I_DIA_MENOS_UNIDADES  INTEGER
,I_CIUDAD              INTEGER
,N_BNETO_CIUDAD        NUMBER
,N_PB_VIRTUALES        NUMBER
,F_ALTA                DATE
,F_MODIFICACION        DATE
,CONSTRAINT            PK_ESTADISTICO 
                       PRIMARY KEY (N_ANYO)	
,CONSTRAINT            FK_ESTADISTICO_TIENDA 
                       FOREIGN KEY (I_TIENDA)   REFERENCES TIENDA(I_TIENDA)
,CONSTRAINT            FK_ESTADISTICO_PRODUCTO 
                       FOREIGN KEY (N_PRODUCTO) REFERENCES PRODUCTO(N_PRODUCTO)
,CONSTRAINT            FK_ESTADISTICO_CIUDAD 
                       FOREIGN KEY (I_CIUDAD)   REFERENCES CIUDAD(I_CIUDAD)
,CONSTRAINT            CK_E_MODIFICACION
                       CHECK (F_MODIFICACION >= F_ALTA));


-- Comentarios 

COMMENT ON TABLE  ESTADISTICO                       IS 'Mdulo estadstico actualizado a partir de las ventas realizadas';
COMMENT ON COLUMN ESTADISTICO.N_ANYO                IS 'Cdigo de identificin del ao a consultar';
COMMENT ON COLUMN ESTADISTICO.N_BNETO_CADENA        IS 'Beneficio neto total de la cadena';
COMMENT ON COLUMN ESTADISTICO.I_TIENDA              IS 'Cdigo de identificacin de la tienda que ms beneficio neto ha conseguido';
COMMENT ON COLUMN ESTADISTICO.N_BNETO_TIENDA        IS 'Total beneficio neto conseguido por la tienda';
COMMENT ON COLUMN ESTADISTICO.N_PRODUCTO            IS 'Cdigo de identificacin del producto ms vendido';
COMMENT ON COLUMN ESTADISTICO.I_PRODUCTO_UNIDADES   IS 'Total de unidades vendidas';
COMMENT ON COLUMN ESTADISTICO.N_HORA_MAS            IS 'Hora del da en la que se han vendido ms productos';
COMMENT ON COLUMN ESTADISTICO.I_HORA_MAS_UNIDADES   IS 'Cifra total de productos vendidos';
COMMENT ON COLUMN ESTADISTICO.N_HORA_MENOS          IS 'Hora del da en la que se han vendido menos productos';
COMMENT ON COLUMN ESTADISTICO.I_HORA_MENOS_UNIDADES IS 'Cifra total de productos vendidos';
COMMENT ON COLUMN ESTADISTICO.N_DIA_MAS             IS 'Da del mes en el que se han vendido ms productos';
COMMENT ON COLUMN ESTADISTICO.I_DIA_MAS_UNIDADES    IS 'Cifra total de productos vendidos';
COMMENT ON COLUMN ESTADISTICO.N_DIA_MENOS           IS 'Da del mes en el que se han vendido menos productos';
COMMENT ON COLUMN ESTADISTICO.I_DIA_MENOS_UNIDADES  IS 'Cifra total de productos vendidos';
COMMENT ON COLUMN ESTADISTICO.I_CIUDAD              IS 'Ciudad en la que se han conseguido ms beneficios';
COMMENT ON COLUMN ESTADISTICO.N_BNETO_CIUDAD        IS 'Beneficio neto conseguido en dicha ciudad';
COMMENT ON COLUMN ESTADISTICO.N_PB_VIRTUALES        IS 'Porcentaje de beneficios conseguidos por tiendas virtuales respecto al total de la cadena';
COMMENT ON COLUMN ESTADISTICO.F_ALTA                IS 'Fecha de incorporacin a la tabla';
COMMENT ON COLUMN ESTADISTICO.F_MODIFICACION        IS 'Fecha ltima modificacin';

/*----------------------------------------------------------------------------*/
/*                      Mensajes de error                                     */
/*----------------------------------------------------------------------------*/

CREATE TABLE     MENSAJE
(V_PROCEDIMIENTO VARCHAR2(50 CHAR)
,N_ERROR         NUMBER(2)
,V_DESCRIPCION   VARCHAR2(100 CHAR)
,F_ALTA          DATE CONSTRAINT NN_M_ALTA NOT NULL
,F_MODIFICACION  DATE
,CONSTRAINT      PK_MENSAJE 
                 PRIMARY KEY (V_PROCEDIMIENTO, N_ERROR)
,CONSTRAINT      CK_M_MODIFICACION
                 CHECK (F_MODIFICACION >= F_ALTA));

-- Comentarios 

COMMENT ON TABLE  MENSAJE                 IS 'Mensajes de error';
COMMENT ON COLUMN MENSAJE.V_PROCEDIMIENTO IS 'Ambito al que est asociado el mensaje';
COMMENT ON COLUMN MENSAJE.N_ERROR         IS 'Cdigo de identificacin del mensaje';
COMMENT ON COLUMN MENSAJE.V_DESCRIPCION   IS 'Descripcin del mensaje';
COMMENT ON COLUMN MENSAJE.F_ALTA          IS 'Fecha de incorporacin a la tabla';
COMMENT ON COLUMN MENSAJE.F_MODIFICACION  IS 'Fecha ltima modificacin';

SPOOL OFF;