SPOOL .\Logs\04-Tipos.log
PROMPT Generando tipos... 

/************************************************************************************************************************
*                                                                                                                       *
* Descripción.: Registro consulta A                                                                                     *
*                                                                                                                       *
* Parámetros recibidos: Año y Mes.                                                                                      *
*                                                                                                                       *
* Información solicitada:                                                                                               *
*                                                                                                                       *
*   El listado de todas las tiendas, incluyendo para cada una:                                                          *
*                                                                                                                       *
*     El número total de productos vendidos en el mes solicitado                                                        *
*     El número de productos diferentes vendidos en el mes solicitado.                                                  *
*     El beneficio neto total obtenido en el mes solicitado                                                             *
*     El porcentaje de beneficio que aporta la tienda en relación al total de la cadena durante el mes solicitado.      *
*     El beneficio neto dividido por el número de empleados de la tienda.                                               *
*                                                                                                                       *
*************************************************************************************************************************/

DROP TYPE TABLA_CONSULTA_A;
CREATE OR REPLACE TYPE OBJ_CONSULTA_A AS OBJECT (

  Tienda                 INTEGER,
  Productos_Vendidos     NUMBER(10),
  Productos_Diferentes   NUMBER(10),
  Beneficio_Neto         NUMBER,
  Beneficio_Neto_Cadena  NUMBER,
  Trabajadores           NUMBER(5)   

);

/

-- Tipo para almacenar el resultado de la consulta

CREATE OR REPLACE TYPE TABLA_CONSULTA_A IS TABLE OF OBJ_CONSULTA_A;

/

/************************************************************************************************************************
*                                                                                                                       *
* Descripción.: Registro consulta B                                                                                     *
*                                                                                                                       *
* Parámetros recibidos: Año y Mes.                                                                                      *
*                                                                                                                       *
* Información solicitada:                                                                                               *
*                                                                                                                       *
*   El listado de todos los productos del catálogo, incluyendo para cada uno:                                           *
*                                                                                                                       *
*     El identificador EAN13.                                                                                           *
*     Nombre del producto.                                                                                              *
*     Número de unidades vendidas en el mes solicitado.                                                                 *
*     Beneficio neto que ha generado el producto en el mes solicitado.                                                  *
*     Tienda que ha vendido más unidades en el mes solicitado.                                                          *
*     Número de unidades que ha vendido la tienda indicada durante el mes solicitado.                                   *
*                                                                                                                       *
*************************************************************************************************************************/

DROP TYPE TABLA_CONSULTA_B;
CREATE OR REPLACE TYPE OBJ_CONSULTA_B AS OBJECT (

  Identificador_Producto   NUMBER(13),
  Nombre_Producto          VARCHAR2(50 CHAR),
  Unidades_Vendidas        NUMBER(10),
  Beneficio_Neto           NUMBER,
  Tienda                   INTEGER,
  Tienda_Unidades_Vendidas NUMBER(10)  
  
);

/

-- Tipo para almacenar el resultado de la consulta

CREATE OR REPLACE TYPE TABLA_CONSULTA_B IS TABLE OF OBJ_CONSULTA_B;

/ 

/************************************************************************************************************************
*                                                                                                                       *
* Descripción.: Registro consulta C                                                                                     *
*                                                                                                                       *
* Parámetros recibidos: Año y Mes.                                                                                      * 
*                                                                                                                       *
* Información solicitada:                                                                                               *
*                                                                                                                       *
*   El listado de todos los días del mes, incluyendo para cada día:                                                     *
*                                                                                                                       *
*     Beneficio total neto obtenido por toda la cadea ese día.                                                          *
*     Identificador EAN13 del producto más vendido ese día.                                                             *
*     Número de unidades vendidas del producto durante el día.                                                          *
*     Tienda que más beneficio neto ha generado ese día.                                                                *
*     El valor en euros del beneficio generado por la tienda.                                                           *
*                                                                                                                       *
*************************************************************************************************************************/

DROP TYPE TABLA_CONSULTA_C;
CREATE OR REPLACE TYPE OBJ_CONSULTA_C AS OBJECT (

  Dia                   NUMBER(2),
  Total_Beneficio_neto  NUMBER,
  Producto              NUMBER(13),
  Unidades_Vendidas     NUMBER(10),
  Tienda                INTEGER,
  Tienda_Beneficio_Neto NUMBER   

);

/

-- Tipo para almacenar el resultado de la consulta

CREATE OR REPLACE TYPE TABLA_CONSULTA_C IS TABLE OF OBJ_CONSULTA_C;

/

/************************************************************************************************************************
*                                                                                                                       *
* Descripción.: Registro consulta H                                                                                     *
*                                                                                                                       *
* Parámetros recibidos: Año.                                                                                            * 
*                                                                                                                       *
* Información solicitada:                                                                                               *
*                                                                                                                       *
*   Lista la información asociada al histórico para un año o para todos:                                                *
*     Beneficio neto de toda la cadena.                                                                                 *
*     Identificador de la tienda que más beneficio neto ha conseguido y la cantidad conseguida.                         *
*     Identificador del producto más vendido y el número de unidades vendidas.                                          *
*     La hora del día donde más productos se han vendido y el número de unidades vendidas.                              *
*     La hora del día donde menos productos se han vendido y el número de unidades vendidas.                            *
*     El día del mes donde más productos se han vendido y el número de unidades vendidas.                               *
*     El día del mes donde menos productos se han vendido y el número de unidades vendidas.                             *
*     Ciudad donde más beneficios se han conseguido y la cantidad conseguida.                                           * 
*     Porcentaje de beneficios obtenidos por las tiendas virtuales con respecto a la cadena.                            * 
*                                                                                                                       *
*************************************************************************************************************************/

DROP TYPE TABLA_CONSULTA_H;
CREATE OR REPLACE TYPE OBJ_CONSULTA_H AS OBJECT (

  H_ANYO                NUMBER(4),
  H_BNETO_CADENA        NUMBER,
  H_TIENDA              INTEGER,
  H_BNETO_TIENDA        NUMBER,
  H_PRODUCTO            NUMBER(13),
  H_PRODUCTO_UNIDADES   INTEGER,
  H_HORA_MAS            NUMBER(2),
  H_HORA_MAS_UNIDADES   INTEGER,
  H_HORA_MENOS          NUMBER(2),
  H_HORA_MENOS_UNIDADES INTEGER,
  H_DIA_MAS             NUMBER(2),
  H_DIA_MAS_UNIDADES    INTEGER,
  H_DIA_MENOS           NUMBER(2),
  H_DIA_MENOS_UNIDADES  INTEGER,
  H_CIUDAD              INTEGER,
  H_BNETO_CIUDAD        NUMBER,
  H_PB_VIRTUALES        NUMBER

);

/

-- Tipo para almacenar el resultado de la consulta

CREATE OR REPLACE TYPE TABLA_CONSULTA_H IS TABLE OF OBJ_CONSULTA_H;

/

SPOOL OFF;