SPOOL .\Logs\06-Package_Procedimientos.log
PROMPT Creando Package Procedimientos... 

/************************************************************************************************************************
* Nombre......: PK_PROCEDIMIENTOS                                                                                       *
* Descripcin.: Agrupa los procedimientos auxiliares.                                                                   *
*************************************************************************************************************************/

CREATE OR REPLACE PACKAGE UOC.PK_PROCEDIMIENTOS AS

PROCEDURE usp_insertar_log (

  I_Procedimiento IN LOG_ACTIVIDAD.V_PROCEDIMIENTO%TYPE, 
  I_Entrada       IN LOG_ACTIVIDAD.V_ENTRADA%TYPE,
  I_Ejecucion     IN LOG_ACTIVIDAD.V_EJECUCION%TYPE
  
  );
  
PROCEDURE usp_insertar_tiempo (

  I_Fecha  IN DATE,
  I_Tiempo OUT NOCOPY INTEGER
  
  );
  
END PK_PROCEDIMIENTOS;

/

CREATE OR REPLACE PACKAGE BODY UOC.PK_PROCEDIMIENTOS AS

/****************************************************************************************************************************************
*                                                                                                                                       * 
* Nombre........: usp_insertar_log                                                                                                      *
* Descripcin...: Permite registrar la actividad realizada en la base de datos.                                                         *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Procedimiento (Nombre del procedimiento ejecutado) - VARCHAR2(50)   - Obligatorio                          *
*                          I_Entrada       (Parmetros del procedimiento      ) - VARCHAR2(1000) - Obligatorio                          *
*                          I_Ejecucion     (Resultado de la ejecucin         ) - VARCHAR2(250)  - Obligatorio                          *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 Se incorpora un nuevo registro al log.                                                                                *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_insertar_log (

  I_Procedimiento IN LOG_ACTIVIDAD.V_PROCEDIMIENTO%TYPE, 
  I_Entrada       IN LOG_ACTIVIDAD.V_ENTRADA%TYPE,
  I_Ejecucion     IN LOG_ACTIVIDAD.V_EJECUCION%TYPE

  )

IS
  
  Fecha_Alta DATE;
  
BEGIN

  -- Inicializacin de variables
  
	Fecha_Alta := SYSTIMESTAMP;
  
  INSERT INTO LOG_ACTIVIDAD (V_PROCEDIMIENTO, V_ENTRADA, V_EJECUCION, F_ALTA)
    VALUES (I_Procedimiento, I_Entrada, I_Ejecucion, Fecha_Alta); 

  COMMIT;
  
END usp_insertar_log;

/****************************************************************************************************************************************
*                                                                                                                                       * 
* Nombre........: usp_insertar_tiempo                                                                                                   *
* Descripcin...: Incorpora una nueva fecha a la tabla TIEMPO.                                                                          *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Fecha (Fecha a incorporar                                     ) - DATE    - Obligatorio                    *
*                          I_Tiempo(Identificador de tiempo asociado a la fecha incorporada) - INTEGER                                  *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 Se incorpora un nuevo registro a la tabla tiempo y se retorna el identificador generado.                              *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_insertar_tiempo (

  I_Fecha   IN DATE,
  I_Tiempo  OUT NOCOPY INTEGER
  
  )

IS
  
  Fecha_Alta    DATE;
  I_Anyo        Tiempo.N_ANYO%Type;
  I_Mes         Tiempo.N_MES%Type;
  I_Dia         Tiempo.N_DIA%Type;
  I_Trimestre   Tiempo.N_TRIMESTRE%Type;
  I_Semana      Tiempo.N_SEMANA%Type;
  I_Dia_Semana  Tiempo.N_DIA_SEMANA%Type;
  
BEGIN

  -- Inicializacin de variables
  
  Fecha_Alta   := SYSTIMESTAMP;
  I_Anyo       := TO_NUMBER(TO_CHAR(I_Fecha, 'YYYY'));
  I_Mes        := TO_NUMBER(TO_CHAR(I_Fecha, 'MM'));
  I_Dia        := TO_NUMBER(TO_CHAR(I_Fecha, 'DD'));
  I_Trimestre  := TO_NUMBER(TO_CHAR(I_Fecha, 'Q'));
  I_Semana     := TO_NUMBER(TO_CHAR(I_Fecha, 'WW'));
  I_Dia_Semana := TO_NUMBER(TO_CHAR(I_Fecha,'D'));
  
  -- Inserta la nueva fecha en la tabla
  
  INSERT INTO TIEMPO (F_FECHA, N_ANYO, N_MES, N_DIA, N_TRIMESTRE, N_SEMANA, N_DIA_SEMANA, F_ALTA)
    VALUES (I_Fecha, I_Anyo, I_Mes, I_Dia, I_Trimestre, I_Semana, I_Dia_Semana, Fecha_Alta); 
  
  -- Recupera el identificador de registro asociado
  
  SELECT T.I_Tiempo INTO I_Tiempo FROM TIEMPO T
     WHERE T.F_FECHA = I_Fecha;
	 
END usp_insertar_tiempo;

END PK_PROCEDIMIENTOS;

/

SPOOL OFF;