SPOOL .\Logs\07-Package_Funciones.log
PROMPT Creando Package Funciones... 

/************************************************************************************************************************
* Nombre......: PK_FUNCIONES                                                                                            *
* Descripcin.: Agrupa las funciones.                                                                                   *
*************************************************************************************************************************/
 
CREATE OR REPLACE PACKAGE UOC.PK_FUNCIONES AS

FUNCTION f_es_fecha(I_Fecha IN VARCHAR2) RETURN BOOLEAN;

FUNCTION f_es_numero(I_Numero IN VARCHAR2) RETURN BOOLEAN;

FUNCTION f_mensaje(I_Procedimiento IN VARCHAR2, I_Error IN NUMBER) RETURN VARCHAR2;

FUNCTION f_tiempo(I_Fecha IN DATE) RETURN INTEGER;

END PK_FUNCIONES;

/

CREATE OR REPLACE PACKAGE BODY UOC.PK_FUNCIONES AS

/****************************************************************************************************************************************
*                                                                                                                                       *
* Nombre........: f_es_fecha                                                                                                            *
* Descripcin...: Verifica que la fecha informada es correcta.                                                                          *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Fecha (Fecha a verificar        ) - VARCHAR2  - Opcional                                                   *
*                 OUTPUT.:         (Resultado de la ejecucin) - BOOLEAN                                                                *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 TRUE  - La fecha informada es correcta.                                                                               *
*                 FALSE - La fecha informada no es correcta.                                                                            *
*                                                                                                                                       *
*****************************************************************************************************************************************/

FUNCTION f_es_fecha (I_Fecha IN VARCHAR2) RETURN BOOLEAN

AS 

  Fecha Date;

BEGIN
	
  Fecha := TO_DATE(I_Fecha);
  RETURN TRUE;

  EXCEPTION

    WHEN OTHERS THEN
		RETURN FALSE;
		
END;

/****************************************************************************************************************************************
*                                                                                                                                       *
* Nombre........: f_es_numero                                                                                                           *
* Descripcin...: Verifica que un campo numrico es correcto.                                                                           *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Numero (Numero a verificar       ) - VARCHAR2  - Opcional                                                  *
*                 OUTPUT.:          (Resultado de la ejecucin) - BOOLEAN                                                               *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 TRUE  - El nmero informado es correcto.                                                                              *
*                 FALSE - El nmero informado es incorrecto.                                                                            *
*                                                                                                                                       *
*****************************************************************************************************************************************/

FUNCTION f_es_numero (I_Numero IN VARCHAR2) RETURN BOOLEAN

AS 

  Numero NUMBER;

BEGIN
	
  Numero := TO_NUMBER(I_Numero);
  RETURN TRUE;

  EXCEPTION

    WHEN OTHERS THEN
		RETURN FALSE;
		
END;

/****************************************************************************************************************************************
*                                                                                                                                       *
* Nombre........: f_mensaje                                                                                                             *
* Descripcin...: Retorna el mesaje correspondiente al procedimiento y nmero indicado.                                                 *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Procedimiento (Nombre del procedimiento          ) - VARCHAR2 - Opcional                                   *
*                          I_Error         (Identificador del error solicitado) - NUMBER   - Opcional                                   *  
*                 OUTPUT.:                 (Resultado de la ejecucin         ) - VARCHAR2                                              *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 El mensaje correspondiente al parmetro y nmero de error solicitado.                                                 *
*                 Si no existe, retorna 'El mensaje solicitado no existe'                                                               *
*                                                                                                                                       *
*****************************************************************************************************************************************/

FUNCTION f_mensaje (I_Procedimiento IN VARCHAR2, I_Error IN NUMBER) RETURN VARCHAR2

AS 

  Registros     INTEGER;
  Texto_Mensaje VARCHAR2(100 CHAR);

BEGIN
	
  SELECT COUNT(*) INTO Registros FROM MENSAJE
    WHERE V_PROCEDIMIENTO = I_PROCEDIMIENTO AND
	      N_ERROR = I_Error;

  IF (Registros = 0) THEN
	RETURN 'El mensaje solictado no existe';
  END IF;
 
  SELECT MAX(V_DESCRIPCION) INTO Texto_Mensaje FROM MENSAJE
    WHERE  V_PROCEDIMIENTO = I_PROCEDIMIENTO AND
	       N_ERROR = I_Error;

  RETURN Texto_Mensaje;
  		  
  EXCEPTION

    WHEN OTHERS THEN
		RETURN 'El mensaje solicitado no existe';
		
END;

/****************************************************************************************************************************************
*                                                                                                                                       *
* Nombre........: f_tiempo                                                                                                              *
* Descripcin...: Retorna el identificador de tiempo correspondiente a la fecha indicada                                                *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Fecha (Fecha a localizar        ) - DATE                                                                   *
*                 OUTPUT.:         (Resultado de la ejecucin) - INTEGER                                                                *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 El identificador de tiempo correspondiente a la fecha indicada.                                                       *
*                 Si no existe retorna un cero.                                                                                         *
*                                                                                                                                       *
*****************************************************************************************************************************************/

FUNCTION f_tiempo (I_Fecha IN DATE) RETURN INTEGER

AS 

  Registros INTEGER;
  Id_Tiempo INTEGER;

BEGIN
	
  SELECT COUNT(*) INTO Registros FROM TIEMPO
    WHERE F_FECHA = I_Fecha;

  IF (Registros = 0) THEN
	RETURN 0;
  END IF;
  
  SELECT I_Tiempo INTO Id_Tiempo FROM TIEMPO
    WHERE F_FECHA = I_Fecha;

  RETURN Id_Tiempo;
		  
  EXCEPTION

    WHEN OTHERS THEN
		RETURN 0;
		
END;

END PK_FUNCIONES;

/ 

SPOOL OFF;