SPOOL .\Logs\08-Package_Verificacion.log
PROMPT Creando Package Verificacin... 

/************************************************************************************************************************
* Nombre......: PK_VERIFICACION                                                                                         *
* Descripcin.: Agrupa los procedimientos de verificacin.                                                              *
*************************************************************************************************************************/
 
CREATE OR REPLACE PACKAGE UOC.PK_VERIFICACION AS

PROCEDURE usp_verificar_tienda (

  I_Tienda IN Tienda.I_Tienda%Type,
  O_RSP    OUT NOCOPY VARCHAR2
  
  );

PROCEDURE usp_verificar_nombre (

  I_Tienda IN Tienda.I_Tienda%Type,
  I_Nombre IN Tienda.V_Nombre%Type,
  O_RSP    OUT NOCOPY VARCHAR2

  );

PROCEDURE usp_verificar_ciudad (

  I_Ciudad IN Ciudad.I_Ciudad%Type,
  O_RSP    OUT NOCOPY VARCHAR2

  );

PROCEDURE usp_verificar_region (

  I_Region IN Region.I_Region%Type,
  O_RSP    OUT NOCOPY VARCHAR2

  );

PROCEDURE usp_verificar_email (

  I_Email IN Tienda.V_Email%Type,
  O_RSP   OUT NOCOPY VARCHAR2

  );
	
PROCEDURE usp_verificar_trabajadores (

  I_Trabajadores IN Tienda.N_Trabajadores%Type,
  O_RSP          OUT NOCOPY VARCHAR2

  );

PROCEDURE usp_verificar_ubicacion (

  I_Ciudad IN Ciudad.I_Ciudad%Type,
  I_Region IN Region.I_Region%Type,
  O_RSP    OUT NOCOPY VARCHAR2

  );
  
PROCEDURE usp_verificar_producto (

  I_Producto     IN Producto.N_Producto%Type,
  I_Comprobacion IN VARCHAR2,
  O_RSP          OUT NOCOPY VARCHAR2
  
  );
  
PROCEDURE usp_verificar_anyo (

  I_Anyo IN VARCHAR2,
  O_RSP  OUT NOCOPY VARCHAR2
  
  );
  
PROCEDURE usp_verificar_mes (

  I_Mes IN VARCHAR2,
  O_RSP OUT NOCOPY VARCHAR2
  
  );

PROCEDURE usp_verificar_tiempo (

  I_Tiempo IN VARCHAR2,
  O_RSP    OUT NOCOPY VARCHAR2
  
  );

PROCEDURE usp_verificar_hora (

  I_Hora IN VARCHAR2,
  O_RSP  OUT NOCOPY VARCHAR2
  
  );

PROCEDURE usp_verificar_cantidad_ventas (

  I_Cantidad_Ventas IN VARCHAR2,
  O_RSP             OUT NOCOPY VARCHAR2
  
  );

PROCEDURE usp_verificar_precio_bruto (

  I_Precio_Bruto IN VARCHAR2,
  O_RSP          OUT NOCOPY VARCHAR2
  
  );

PROCEDURE usp_verificar_beneficio_neto (

  I_Beneficio_Neto IN VARCHAR2,
  O_RSP            OUT NOCOPY VARCHAR2
  
  );
  
END PK_VERIFICACION;

/

CREATE OR REPLACE PACKAGE BODY UOC.PK_VERIFICACION AS

/****************************************************************************************************************************************
*                                                                                                                                       *
* Nombre........: usp_verificar_tienda                                                                                                  *
* Descripcin...: Verifica la existencia de la tienda                                                                                   *
*                 Los campos opcionales puede estar informados o ser NULL                                                               *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Tienda (Cdigo de identificacin de la tienda ) - Integer  - Opcional                                      *
*                 OUTPUT.: O_RSP    (Resultado de la ejecucin             ) - VARCHAR2                                                 *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 OK - El cdigo de tienda informado es correcto.                                                                       *
*                 ERROR: No se informa el cdigo de identificacin de la tienda.                                                        *
*                 ERROR: La tienda informada no existe.                                                                                 *
*                 ERROR: La tienda informada est anulada                                                                               *
*                 ERROR: SQLCODE - SQLERRM                                                                                              *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_verificar_tienda (

  I_Tienda IN Tienda.I_Tienda%Type,
  O_RSP    OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento           VARCHAR2(50 CHAR);
  Parametros_entrada      VARCHAR2(1000 CHAR);
  Registros               INTEGER;
  IN_Tienda               INTEGER;
  
  Err_Codigo              NUMBER;
  Err_Descripcion         VARCHAR2(200 CHAR);
	
  Ex_Tienda               EXCEPTION;
  Ex_Tienda_Inexistente   EXCEPTION;
  Ex_Tienda_Eliminada     EXCEPTION;

BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_VERIFICACION.usp_verificar_tienda';
  Parametros_entrada  := '(' || I_Tienda || ')';
  O_RSP               := 'OK';
  IN_Tienda           := I_Tienda;
  
  -- Verificacin de datos
  
  IF (I_Tienda IS NULL) THEN
    RAISE Ex_Tienda;
  END IF;
  
  SELECT COUNT(*) INTO Registros FROM TIENDA
    WHERE I_TIENDA = IN_Tienda;
  
  IF (Registros = 0) THEN
    RAISE Ex_Tienda_Inexistente;
  END IF;
  
  SELECT COUNT(*) INTO Registros FROM TIENDA
    WHERE I_TIENDA = IN_Tienda and F_ELIMINACION IS NOT NULL;
      
  IF (Registros = 1) THEN
    RAISE Ex_Tienda_Eliminada;
  END IF;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
  
  EXCEPTION
  
    WHEN Ex_Tienda THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_tienda',1));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
	  dbms_output.put_line(TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_tienda',1)));    -- Verificar
	  
    WHEN Ex_Tienda_Inexistente THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_tienda',2));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				

    WHEN Ex_Tienda_Eliminada THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_tienda',3));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
	  
    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_verificar_tienda;

/****************************************************************************************************************************************
*                                                                                                                                       *
* Nombre........: usp_verificar_nombre                                                                                                  *
* Descripcin...: Verifica el nombre de la tienda                                                                                       *
*                 Los campos opcionales puede estar informados o ser NULL                                                               *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Tienda (Cdigo de identificacin de la tienda) - Integer            - Opcional                             *
*                          I_Nombre (Nombre a verificar                   ) - VARCHAR2(250 CHAR) - Opcional                             *
*                 OUTPUT.: O_RSP    (Resultado de la ejecucin            ) - VARCHAR2                                                  *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 OK - El nombre de la tienda informado es correcto                                                                     *
*                 ERROR: No se informa el nombre de la tienda.                                                                          *
*                 ERROR: El nombre informado est asociado a otra tienda.                                                               *
*                 ERROR: SQLCODE - SQLERRM                                                                                              *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_verificar_nombre (

  I_Tienda IN Tienda.I_Tienda%Type,
  I_Nombre IN Tienda.V_Nombre%Type,
  O_RSP    OUT NOCOPY VARCHAR2
  
  )

IS

  Procedimiento           VARCHAR2(50 CHAR);
  Parametros_entrada      VARCHAR2(1000 CHAR);
  Registros               INTEGER;
  IN_Tienda               INTEGER;
  
  Err_Codigo              NUMBER;
  Err_Descripcion         VARCHAR2(200 CHAR);
	
  Ex_Nombre               EXCEPTION;
  Ex_Nombre_Existente     EXCEPTION;

BEGIN

  -- Inicializacin de variables
  
  Procedimiento       := 'PK_VERIFICACION.usp_verificar_nombre';
  Parametros_entrada  := '(' || I_Tienda || ', ' || I_Nombre || ')';
  O_RSP               := 'OK';
  IN_Tienda           := I_Tienda;
  
  -- Verificacin de datos
  
  IF (I_Nombre IS NULL or TRIM(I_Nombre) IS NULL) THEN
    RAISE Ex_Nombre;
  END IF;
  
  IF (I_Tienda IS NOT NULL) THEN
  
	SELECT COUNT(*) INTO Registros FROM TIENDA
		WHERE I_TIENDA <> IN_Tienda AND LOWER(V_Nombre) = LOWER(I_Nombre);
  
	IF (Registros <> 0) THEN
		RAISE Ex_Nombre_Existente;
	END IF;
  
  END IF;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
  
  EXCEPTION
  
    WHEN Ex_Nombre THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_nombre',1));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
    
    WHEN Ex_Nombre_Existente THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_nombre',2));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
  
    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_verificar_nombre;

/****************************************************************************************************************************************
*                                                                                                                                       *
* Nombre........: usp_verificar_ciudad                                                                                                  *
* Descripcin...: Verifica la ciudad en la que est ubicada la tienda                                                                   *
*                 Los campos opcionales puede estar informados o ser NULL                                                               *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Ciudad (Cdigo de la ciudad en la que est ubicada) - Integer  - Opcional                                  *
*                 OUTPUT.: O_RSP    (Resultado de la ejecucin                 ) - VARCHAR2                                             *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 OK - El nombre de la ciudad informada es correcto.                                                                    *
*                 ERROR: No se informa la ciudad en la que est ubicada la tienda.                                                      *
*                 ERROR: La ciudad informada no existe.                                                                                 *
*                 ERROR: La ciudad informada est anulada.                                                                              *
*                 ERROR: SQLCODE - SQLERRM                                                                                              *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_verificar_ciudad (

  I_Ciudad IN Ciudad.I_Ciudad%Type,
  O_RSP    OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento           VARCHAR2(50 CHAR);
  Parametros_entrada      VARCHAR2(1000 CHAR);
  Registros               INTEGER;
  IN_Ciudad               INTEGER;
  
  Err_Codigo              NUMBER;
  Err_Descripcion         VARCHAR2(200 CHAR);
	
  Ex_Ciudad               EXCEPTION;
  Ex_Ciudad_Inexistente   EXCEPTION;
  Ex_Ciudad_Eliminada     EXCEPTION;

BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_VERIFICACION.usp_verificar_ciudad';
  Parametros_entrada  := '(' || I_Ciudad || ')';
  O_RSP               := 'OK';
  IN_Ciudad           := I_Ciudad;
  
  -- Verificacin de datos
  
  IF (I_Ciudad IS NULL) THEN
    RAISE Ex_Ciudad;
  END IF;
  
  SELECT COUNT(*) INTO Registros FROM CIUDAD
    WHERE I_CIUDAD = IN_Ciudad;
  
  IF (Registros = 0) THEN
    RAISE Ex_Ciudad_Inexistente;
  END IF;
  
  SELECT COUNT(*) INTO Registros FROM CIUDAD
    WHERE I_CIUDAD = IN_Ciudad and F_ELIMINACION IS NOT NULL;
      
  IF (Registros = 1) THEN
    RAISE Ex_Ciudad_Eliminada;
  END IF;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
  
  EXCEPTION
  
    WHEN Ex_Ciudad THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_ciudad',1));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
    
    WHEN Ex_Ciudad_Inexistente THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_ciudad',2));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				

    WHEN Ex_Ciudad_Eliminada THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_ciudad',3));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
	  
    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_verificar_ciudad;

/****************************************************************************************************************************************
*                                                                                                                                       *
* Nombre........: usp_verificar_region                                                                                                  *
* Descripcin...: Verifica la regin en la que est ubicada la tienda                                                                   *
*                 Los campos opcionales puede estar informados o ser NULL                                                               *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Region (Cdigo de la comunidad autonoma a la que pertenece la tienda) - Integer  - Opcional                *
*                 OUTPUT.: O_RSP    (Resultado de la ejecucin                                   ) - VARCHAR2                           *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 OK - El nombre de la regin informada es correcto.                                                                    *
*                 ERROR: No se informa la regin en la que est ubicada la tienda.                                                      *
*                 ERROR: La regin informada no existe.                                                                                 *
*                 ERROR: La regin informada est anulada.                                                                              *
*                 ERROR: SQLCODE - SQLERRM                                                                                              *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_verificar_region (

  I_Region IN Region.I_Region%Type,
  O_RSP    OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento           VARCHAR2(50 CHAR);
  Parametros_entrada      VARCHAR2(1000 CHAR);
  Registros               INTEGER;
  IN_Region               INTEGER;
  
  Err_Codigo              NUMBER;
  Err_Descripcion         VARCHAR2(200 CHAR);
	
  Ex_Region               EXCEPTION;
  Ex_Region_Inexistente   EXCEPTION;
  Ex_Region_Eliminada     EXCEPTION;

BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_VERIFICACION.usp_verificar_region';
  Parametros_entrada  := '(' || I_Region || ')';
  O_RSP               := 'OK';
  IN_Region           := I_Region;
  
  -- Verificacin de datos
  
  IF (I_Region IS NULL) THEN
    RAISE Ex_Region;
  END IF;
  
  SELECT COUNT(*) INTO Registros FROM REGION
    WHERE I_REGION = IN_Region;
  
  IF (Registros = 0) THEN
    RAISE Ex_Region_Inexistente;
  END IF;
  
  SELECT COUNT(*) INTO Registros FROM REGION
    WHERE I_REGION = IN_Region and F_ELIMINACION IS NOT NULL;
      
  IF (Registros = 1) THEN
    RAISE Ex_Region_Eliminada;
  END IF;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
  
  EXCEPTION
  
    WHEN Ex_Region THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_region',1));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
    
    WHEN Ex_Region_Inexistente THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_region',2));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				

    WHEN Ex_Region_Eliminada THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_region',3));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
	  
    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_verificar_region;

/****************************************************************************************************************************************
*                                                                                                                                       *
* Nombre........: usp_verificar_email                                                                                                   *
* Descripcin...: Verifica el E_mail del gerente de la tienda                                                                           *
*                 Los campos opcionales puede estar informados o ser NULL                                                               *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Email (E_mail del gerente        ) - VARCHAR2(250 CHAR) - Opcional                                         *
*                 OUTPUT.: O_RSP   (Resultado de la ejecucin ) - VARCHAR2                                                              *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 OK - El nombre de la regin informada es correcto.                                                                    *
*                 ERROR: No se informa el e-mail del gerente de la tienda.                                                              *
*                 ERROR: El e-mail informado no es correcto.                                                                            *
*                 ERROR: SQLCODE - SQLERRM                                                                                              *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_verificar_email (

  I_Email IN Tienda.V_Email%Type,
  O_RSP   OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento           VARCHAR2(50 CHAR);
  Parametros_entrada      VARCHAR2(1000 CHAR);
  Direccion               VARCHAR2(250 CHAR);
  
  Err_Codigo              NUMBER;
  Err_Descripcion         VARCHAR2(200 CHAR);
	
  Ex_Email                EXCEPTION;
  Ex_Email_Incorrecto     EXCEPTION;

BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_VERIFICACION.usp_verificar_email';
  Parametros_entrada  := '(' || I_Email || ')';
  O_RSP               := 'OK';
  
  -- Verificacin de datos
  
  IF (I_Email IS NULL or TRIM(I_Email) IS NULL) THEN
    RAISE Ex_Email;
  END IF;
  
  SELECT REGEXP_SUBSTR(I_Email,'[a-zA-Z0-9._%-]+@[a-zA-Z0-9._%-]+\.[a-zA-Z]{2,4}') INTO Direccion
  FROM  DUAL;
  
  IF (Direccion IS NULL) THEN
    RAISE Ex_Email_Incorrecto;
  END IF;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
  
  EXCEPTION
  
    WHEN Ex_Email THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_email',1));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
	 
	WHEN Ex_Email_Incorrecto THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_email',2));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
    
    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_verificar_email;

/****************************************************************************************************************************************
*                                                                                                                                       *
* Nombre........: usp_verificar_trabajadores                                                                                            *
* Descripcin...: Verifica que el nmero de trabajadores informados sea correcto                                                        *
*                 Los campos opcionales puede estar informados o ser NULL                                                               *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Trabajadores (Nmero de trabajadores de la tienda) - NUMBER(5) - Opcional                                  *
*                 OUTPUT.: O_RSP          (Resultado de la ejecucin          ) - VARCHAR2                                              *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 OK - El nmero de trabajadores informado es correcto.                                                                 *
*                 ERROR: No se informa el nmero de trabajadores de la tienda.                                                          *
*                 ERROR: El nmero de trabajadores debe ser un valor numrico.                                                          *
*                 ERROR: SQLCODE - SQLERRM                                                                                              *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_verificar_trabajadores (

  I_Trabajadores IN Tienda.N_Trabajadores%Type,
  O_RSP          OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento               VARCHAR2(50 CHAR);
  Parametros_entrada          VARCHAR2(1000 CHAR);
  Numero                      NUMBER(5);
  
  Err_Codigo                  NUMBER;
  Err_Descripcion             VARCHAR2(200 CHAR);
	
  Ex_Trabajadores             EXCEPTION;
  Ex_Trabajadores_Incorrectos EXCEPTION;

BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_VERIFICACION.usp_verificar_trabajadores';
  Parametros_entrada  := '(' || I_Trabajadores || ')';
  O_RSP               := 'OK';
  
  -- Verificacin de datos
  
  IF (I_Trabajadores IS NULL) THEN
    RAISE Ex_Trabajadores;
  END IF;
  
  IF (I_Trabajadores = 0) THEN
    RAISE Ex_Trabajadores_Incorrectos;
  END IF;
  
  SELECT REGEXP_SUBSTR(I_Trabajadores, '^[0-9]+$') INTO Numero FROM DUAL;
  
  IF (Numero IS NULL) THEN
	RAISE Ex_Trabajadores_Incorrectos;
  END IF;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
  
  EXCEPTION
  
    WHEN Ex_Trabajadores THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_trabajadores',1));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
	  
    WHEN Ex_Trabajadores_Incorrectos THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_trabajadores',2));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
	  
    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_verificar_trabajadores;

/****************************************************************************************************************************************
*                                                                                                                                       *
* Nombre........: usp_verificar_ubicacin                                                                                               *
* Descripcin...: Verifica que la ciudad y la regin pertenezcan al mismo pas.                                                         *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Ciudad (Cdigo de la ciudad en la que est ubicada                  ) - Integer  - Obligatorio             *
*                          I_Region (Cdigo de la comunidad autonoma a la que pertenece la tienda) - Integer  - Obligatorio             *
*                 OUTPUT.: O_RSP    (Resultado de la ejecucin                                   ) - VARCHAR2                           *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 OK - El nombre de la ciudad informada es correcto.                                                                    *
*                 ERROR: El pas de la ciudad y la regin no es coincidente.      	                                                    *
*                 ERROR: SQLCODE - SQLERRM                                                                                              *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_verificar_ubicacion (

  I_Ciudad IN Ciudad.I_Ciudad%Type,
  I_Region IN Region.I_Region%Type,
  O_RSP    OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento           VARCHAR2(50 CHAR);
  Parametros_entrada      VARCHAR2(1000 CHAR);
  Pais_Ciudad             VARCHAR2(3 CHAR);
  Pais_Region             VARCHAR2(3 CHAR);
  IN_Ciudad               INTEGER;
  IN_Region               INTEGER;  
  
  Err_Codigo              NUMBER;
  Err_Descripcion         VARCHAR2(200 CHAR);
	
  Ex_Ubicacion_Erronea    EXCEPTION;

BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_VERIFICACION.usp_verificar_ubicacion';
  Parametros_entrada  := '(' || I_Ciudad || ', ' || I_Region || ')';
  O_RSP               := 'OK';
  IN_Ciudad           := I_Ciudad;
  IN_Region           := I_Region;
  
  -- Verificacin de datos
  
  SELECT MAX(V_PAIS) INTO Pais_Ciudad FROM CIUDAD
    WHERE I_CIUDAD = I_Ciudad;
	

  SELECT MAX(V_PAIS) INTO Pais_Region FROM REGION
    WHERE I_REGION = I_Region;
  
  IF (Pais_Ciudad <> Pais_Region) THEN
    RAISE Ex_Ubicacion_Erronea;
  END IF;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
  
  EXCEPTION
  
    WHEN Ex_Ubicacion_Erronea THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_ubicacion',1));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
    
    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_verificar_ubicacion;

/****************************************************************************************************************************************
*                                                                                                                                       *
* Nombre........: usp_verificar_producto                                                                                                *
* Descripcin...: Verifica la existencia del producto.                                                                                  *
*                 Los campos opcionales puede estar informados o ser NULL                                                               *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Producto     (Cdigo de identificin del producto) - NUMBER(13)      - Opcional                            *
*                          I_Comprobacion (A - Alta, E - Eliminacin          ) - VARCHAR(1 CHAR) - Obligatorio                         *
*                 OUTPUT.: O_RSP          (Resultado de la ejecucin          ) - VARCHAR2                                              *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 OK - El cdigo del producto informado es correcto.                                                                    *
*                 ERROR: No se informa el cdigo de producto.                                                                           *
*                 ERROR: El cdigo de producto informado no es correcto.                                                                *
*                 ERROR: El producto informado no existe.                                                                               *
*                 ERROR: El producto informado est anulado.                                                                            *
*                 ERROR: SQLCODE - SQLERRM                                                                                              *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_verificar_producto (

  I_Producto     IN Producto.N_Producto%Type,
  I_Comprobacion IN VARCHAR2,
  O_RSP          OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento           VARCHAR2(50 CHAR);
  Parametros_entrada      VARCHAR2(1000 CHAR);
  Registros               INTEGER;
  Longitud                INTEGER;
  
  Err_Codigo              NUMBER;
  Err_Descripcion         VARCHAR2(200 CHAR);
  
  Suma                    NUMBER;
  Multiple                NUMBER;
	
  Ex_Producto             EXCEPTION;
  Ex_Producto_Incorrecto  EXCEPTION;
  Ex_Producto_Inexistente EXCEPTION;
  Ex_Producto_Eliminado   EXCEPTION;

BEGIN

  -- Inicializacin de variables
  
  Procedimiento       := 'PK_VERIFICACION.usp_verificar_producto';
  Parametros_entrada  := '(' || I_Producto || ')';
  O_RSP               := 'OK';
  
  -- Verificacin de datos
  
  IF (I_Producto IS NULL) THEN
    RAISE Ex_Producto;
  END IF;

  SELECT LENGTH(TO_CHAR(I_PRODUCTO)) INTO Longitud  FROM DUAL;
  
  IF (Longitud < 13) THEN 
  	Raise Ex_Producto_Incorrecto;
  END IF;
  
  FOR I IN 1..12 LOOP
	IF MOD(I,2) = 0 Then
		Multiple := 3;
	ELSE
		Multiple := 1;
	END IF;

	Suma := Nvl(Suma, 0) + SUBSTR(I_Producto, I, 1) * Multiple;

  END LOOP;

  IF 10 - Mod(Suma, 10) <> SUBSTR(I_Producto, 13) Then
	RAISE Ex_Producto_Incorrecto;
  END IF;

  IF (I_Comprobacion = 'E') THEN 
  
    SELECT COUNT(*) INTO Registros FROM PRODUCTO
      WHERE N_PRODUCTO = I_Producto;
  
    IF (Registros = 0) THEN
      RAISE Ex_Producto_Inexistente;
    END IF;
  
    SELECT COUNT(*) INTO Registros FROM PRODUCTO
      WHERE N_PRODUCTO = I_Producto and F_ELIMINACION IS NOT NULL;
      
    IF (Registros = 1) THEN
      RAISE Ex_Producto_Eliminado;
    END IF;
  
  END IF;
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
  
  EXCEPTION
  
    WHEN Ex_Producto THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_producto',1));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
	
	WHEN Ex_Producto_Incorrecto THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_producto',2));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
    
    WHEN Ex_Producto_Inexistente THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_producto',3));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				

    WHEN Ex_Producto_Eliminado THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_producto',4));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
	  
    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_verificar_producto;

/****************************************************************************************************************************************
*                                                                                                                                       *
* Nombre........: usp_verificar_anyo                                                                                                    *
* Descripcin...: Verifica que se trate de un nmero y que la longitud sea igual a cuatro.                                              *
*                 Los campos opcionales puede estar informados o ser NULL                                                               *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Anyo(Ao a verificar          ) - VARCHAR2 - Opcional                                                      *
*                 OUTPUT.: O_RSP (Resultado de la ejecucin) - VARCHAR2                                                                 *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 OK - El ao a verificar es correcto.                                                                                  *
*                 ERROR: No se informa el ao a consultar.                                                                              *
*                 ERROR: El ao recibido como parmetro no es correcto.                                                                 *
*                 ERROR: SQLCODE - SQLERRM                                                                                              *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_verificar_anyo (

  I_Anyo IN VARCHAR2,
  O_RSP  OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento           VARCHAR2(50 CHAR);
  Parametros_entrada      VARCHAR2(1000 CHAR);
  Registros               INTEGER;
  
  Err_Codigo              NUMBER;
  Err_Descripcion         VARCHAR2(200 CHAR);
	
  Ex_Anyo                 EXCEPTION;
  Ex_Anyo_Incorrecto      EXCEPTION;
  
BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_VERIFICACION.usp_verificar_anyo';
  Parametros_entrada  := '(' || I_Anyo || ')';
  O_RSP               := 'OK';
  
  -- Verificacin de datos
  
  IF (I_Anyo IS NULL) THEN
    RAISE Ex_Anyo;
  END IF;
  
  IF (LENGTH(I_Anyo) <> 4 or NOT PK_FUNCIONES.f_es_numero(I_Anyo)) THEN
    RAISE Ex_Anyo_Incorrecto;
  END IF;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
  
  EXCEPTION
  
    WHEN Ex_Anyo THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_anyo',1));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
	
	WHEN Ex_Anyo_Incorrecto THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_anyo',2));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
    
    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_verificar_anyo;

/****************************************************************************************************************************************
*                                                                                                                                       *
* Nombre........: usp_verificar_mes                                                                                                     *
* Descripcin...: Verifica que se trate de un nmero y que su valor este comprendido entre 1 y 12.                                      *
*                 Los campos opcionales puede estar informados o ser NULL                                                               *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Mes (Mes a verificar          ) - VARCHAR2 - Opcional                                                      *
*                 OUTPUT.: O_RSP (Resultado de la ejecucin) - VARCHAR2                                                                 *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 OK - El mes a verificar es correcto.                                                                                  *
*                 ERROR: No se informa el mes a consultar.                                                                              *
*                 ERROR: El mes recibido como parmetro no es correcto.                                                                 *
*                 ERROR: SQLCODE - SQLERRM                                                                                              *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_verificar_mes (

  I_Mes IN VARCHAR2,
  O_RSP OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento          VARCHAR2(50 CHAR);
  Parametros_entrada     VARCHAR2(1000 CHAR);
  Registros              INTEGER;
  
  Mes                    NUMBER;
  
  Err_Codigo             NUMBER;
  Err_Descripcion        VARCHAR2(200 CHAR);
  
  Ex_Mes                 EXCEPTION;
  Ex_Mes_Incorrecto      EXCEPTION;
  
BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_VERIFICACION.usp_verificar_mes';
  Parametros_entrada  := '(' || I_Mes || ')';
  O_RSP               := 'OK';
  
  -- Verificacin de datos
  
  IF (I_Mes IS NULL) THEN
    RAISE Ex_Mes;
  END IF;
  
  IF NOT PK_FUNCIONES.f_es_numero(I_Mes) THEN
    RAISE Ex_Mes_Incorrecto;
  END IF;
 
  MES := TO_NUMBER(I_MES);
  
  IF (MES < 1 or MES > 12) THEN
    RAISE Ex_Mes_Incorrecto;
  END IF;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
  
  EXCEPTION
  
    WHEN Ex_Mes THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_mes',1));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
	
	WHEN Ex_Mes_Incorrecto THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_mes',2));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
    
    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_verificar_mes;

/****************************************************************************************************************************************
*                                                                                                                                       *
* Nombre........: usp_verificar_tiempo                                                                                                  *
* Descripcin...: Verifica que se trate de una fecha.                                                                                   *
*                 Los campos opcionales puede estar informados o ser NULL                                                               *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Tiempo (Fecha a verificar        ) - VARCHAR2 - Opcional                                                   *
*                 OUTPUT.: O_RSP    (Resultado de la ejecucin) - VARCHAR2                                                              *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 OK - La fecha a verificar es correcta.                                                                                *
*                 ERROR: No se informa la fecha a verificar.                                                                            *
*                 ERROR: La fecha recibida como parmetro no es correcta.                                                               *
*                 ERROR: SQLCODE - SQLERRM                                                                                              *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_verificar_tiempo (

  I_Tiempo IN VARCHAR2,
  O_RSP    OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento          VARCHAR2(50 CHAR);
  Parametros_entrada     VARCHAR2(1000 CHAR);
  Registros              INTEGER;
  
  Tiempo                 Date;
  
  Err_Codigo             NUMBER;
  Err_Descripcion        VARCHAR2(200 CHAR);
  
  Ex_Tiempo              EXCEPTION;
  Ex_Tiempo_Incorrecto   EXCEPTION;
  
BEGIN

  -- Inicializacin de variables
  
  Procedimiento       := 'PK_VERIFICACION.usp_verificar_tiempo';
  Parametros_entrada  := '(' || I_Tiempo || ')';
  O_RSP               := 'OK';
  
  -- Verificacin de datos
  
  IF (I_Tiempo IS NULL) THEN
    RAISE Ex_Tiempo;
  END IF;
  
  IF NOT PK_FUNCIONES.f_es_fecha(I_Tiempo) THEN
    RAISE Ex_Tiempo_Incorrecto;
  END IF;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
  
  EXCEPTION
  
    WHEN Ex_Tiempo THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_tiempo',1));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
	
	WHEN Ex_Tiempo_Incorrecto THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_tiempo',2));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
    
    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_verificar_tiempo;

/****************************************************************************************************************************************
*                                                                                                                                       *
* Nombre........: usp_verificar_hora                                                                                                    *
* Descripcin...: Verifica que se trate de un nmero y que su valor este comprendido entre 0 y 23.                                      *
*                 Los campos opcionales puede estar informados o ser NULL                                                               *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Hora (Hora a verificar         ) - VARCHAR2 - Opcional                                                     *
*                 OUTPUT.: O_RSP  (Resultado de la ejecucin) - VARCHAR2                                                                *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 OK - La hora a verificar es correcta.                                                                                 *
*                 ERROR: No se informa la hora a verificar.                                                                             *
*                 ERROR: La hora recibida como parmetro no es correcta.                                                                *
*                 ERROR: SQLCODE - SQLERRM                                                                                              *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_verificar_hora (

  I_Hora IN VARCHAR2,
  O_RSP  OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento          VARCHAR2(50 CHAR);
  Parametros_entrada     VARCHAR2(1000 CHAR);
  Registros              INTEGER;
  
  Hora                   NUMBER;
  
  Err_Codigo             NUMBER;
  Err_Descripcion        VARCHAR2(200 CHAR);
  
  Ex_Hora                EXCEPTION;
  Ex_Hora_Incorrecta     EXCEPTION;
  
BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_VERIFICACION.usp_verificar_hora';
  Parametros_entrada  := '(' || I_Hora || ')';
  O_RSP               := 'OK';
  
  -- Verificacin de datos
  
  IF (I_Hora IS NULL) THEN
    RAISE Ex_Hora;
  END IF;
  
  IF NOT PK_FUNCIONES.f_es_numero(I_Hora) THEN
    RAISE Ex_Hora_Incorrecta;
  END IF;
 
  Hora := TO_NUMBER(I_Hora);
  
  IF (Hora < 0 or hora > 23) THEN
    RAISE Ex_Hora_Incorrecta;
  END IF;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
  
  EXCEPTION
  
    WHEN Ex_Hora THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_hora',1));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
	
	WHEN Ex_Hora_Incorrecta THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_hora',2));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
    
    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_verificar_hora;

/****************************************************************************************************************************************
*                                                                                                                                       *
* Nombre........: usp_verificar_cantidad_ventas                                                                                         *
* Descripcin...: Verifica que se trate de un nmero y que su valor sea mayor de cero.                                                  *
*                 Los campos opcionales puede estar informados o ser NULL                                                               *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Cantidad_Ventas (Cantidad de ventas a verificar) - VARCHAR2 - Opcional                                     *
*                 OUTPUT.: O_RSP             (Resultado de la ejecucin     ) - VARCHAR2                                                *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 OK - La cantidad de ventas a verificar es correcta.                                                                   *
*                 ERROR: No se informa la cantidad de ventas a verificar                                                                *
*                 ERROR: La cantidad de ventas recibida como parmetro no es correcta.                                                  *
*                 ERROR: SQLCODE - SQLERRM                                                                                              *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_verificar_cantidad_ventas (

  I_Cantidad_Ventas IN VARCHAR2,
  O_RSP             OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento          VARCHAR2(50 CHAR);
  Parametros_entrada     VARCHAR2(1000 CHAR);
  Registros              INTEGER;
  
  Cantidad_Ventas        INTEGER;
  
  Err_Codigo             NUMBER;
  Err_Descripcion        VARCHAR2(200 CHAR);
  
  Ex_Cantidad            EXCEPTION;
  Ex_Cantidad_Incorrecta EXCEPTION;
  
BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_VERIFICACION.usp_verificar_cantidad_ventas';
  Parametros_entrada  := '(' || I_Cantidad_Ventas || ')';
  O_RSP               := 'OK';
  
  -- Verificacin de datos
  
  IF (I_Cantidad_Ventas IS NULL) THEN
    RAISE Ex_Cantidad;
  END IF;
  
  IF NOT PK_FUNCIONES.f_es_numero(I_Cantidad_Ventas) THEN
    RAISE Ex_Cantidad_Incorrecta;
  END IF;
 
  Cantidad_Ventas := TO_NUMBER(I_Cantidad_Ventas);
  
  IF (Cantidad_Ventas <= 0) THEN
    RAISE Ex_Cantidad_Incorrecta;
  END IF;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
  
  EXCEPTION
  
    WHEN Ex_Cantidad THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_cantidad_ventas',1));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
	
	WHEN Ex_Cantidad_Incorrecta THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_cantidad_ventas',2));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
    
    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_verificar_cantidad_ventas;

/****************************************************************************************************************************************
*                                                                                                                                       *
* Nombre........: usp_verificar_precio_bruto                                                                                            *
* Descripcin...: Verifica que se trate de un nmero y que su valor sea mayor de cero.                                                  *
*                 Los campos opcionales puede estar informados o ser NULL                                                               *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Precio_Bruto (Precio bruto a verificar ) - VARCHAR2 - Opcional                                             *
*                 OUTPUT.: O_RSP          (Resultado de la ejecucin) - VARCHAR2                                                        *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 OK - El precio bruto a verificar es correcto.                                                                         *
*                 ERROR: No se informa el precio bruto a verificar.                                                                     *
*                 ERROR: El precio bruto recibido como parmetro no es correcto.                                                        *
*                 ERROR: SQLCODE - SQLERRM                                                                                              *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_verificar_precio_bruto (

  I_Precio_Bruto IN VARCHAR2,
  O_RSP          OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento        VARCHAR2(50 CHAR);
  Parametros_entrada   VARCHAR2(1000 CHAR);
  Registros            INTEGER;
  
  Precio_Bruto         NUMBER;
  
  Err_Codigo           NUMBER;
  Err_Descripcion      VARCHAR2(200 CHAR);
  
  Ex_Precio            EXCEPTION;
  Ex_Precio_Incorrecto EXCEPTION;
  
BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_VERIFICACION.usp_verificar_precio_bruto';
  Parametros_entrada  := '(' || I_Precio_Bruto || ')';
  O_RSP               := 'OK';
  
  -- Verificacin de datos
  
  IF (I_Precio_Bruto IS NULL) THEN
    RAISE Ex_Precio;
  END IF;
  
  IF NOT PK_FUNCIONES.f_es_numero(I_Precio_Bruto) THEN
    RAISE Ex_Precio_Incorrecto;
  END IF;
 
  Precio_Bruto := TO_NUMBER(I_Precio_Bruto);
  
  IF (Precio_Bruto <= 0) THEN
    RAISE Ex_Precio_Incorrecto;
  END IF;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
  
  EXCEPTION
  
    WHEN Ex_Precio THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_precio_bruto',1));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
	
	WHEN Ex_Precio_Incorrecto THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_precio_bruto',2));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
    
    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_verificar_precio_bruto;

/****************************************************************************************************************************************
*                                                                                                                                       *
* Nombre........: usp_verificar_beneficio_neto                                                                                          *
* Descripcin...: Verifica que se trate de un nmero.                                                                                   *
*                 Los campos opcionales puede estar informados o ser NULL                                                               *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Beneficio_Neto (Beneficio neto a verificar ) - VARCHAR2 - Opcional                                         *
*                 OUTPUT.: O_RSP            (Resultado de la ejecucin  ) - VARCHAR2                                                    *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 OK - El beneficio neto a verificar es correcto.                                                                       *
*                 ERROR: No se informa el beneficio neto a verificar.                                                                   *
*                 ERROR: El beneficio neto recibido como parmetro no es correcto.                                                      *
*                 ERROR: SQLCODE - SQLERRM                                                                                              *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_verificar_beneficio_neto (

  I_Beneficio_Neto IN VARCHAR2,
  O_RSP            OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento           VARCHAR2(50 CHAR);
  Parametros_entrada      VARCHAR2(1000 CHAR);
  Registros               INTEGER;
  
  Beneficio_Neto          NUMBER;
  
  Err_Codigo              NUMBER;
  Err_Descripcion         VARCHAR2(200 CHAR);
  
  Ex_Beneficio            EXCEPTION;
  Ex_Beneficio_Incorrecto EXCEPTION;
  
BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_VERIFICACION.usp_verificar_beneficio_neto';
  Parametros_entrada  := '(' || I_Beneficio_Neto || ')';
  O_RSP               := 'OK';
  
  -- Verificacin de datos
  
  IF (I_Beneficio_Neto IS NULL) THEN
    RAISE Ex_Beneficio;
  END IF;
  
  IF NOT PK_FUNCIONES.f_es_numero(I_Beneficio_Neto) THEN
    RAISE Ex_Beneficio_Incorrecto;
  END IF;
 
  Beneficio_Neto := TO_NUMBER(I_Beneficio_Neto);
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
  
  EXCEPTION
  
    WHEN Ex_Beneficio THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_beneficio_neto',1));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
	
	WHEN Ex_Beneficio_Incorrecto THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_VERIFICACION.usp_verificar_beneficio_neto',2));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
    
    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_verificar_beneficio_neto;

END PK_VERIFICACION;

/ 

SPOOL OFF;