SPOOL .\Logs\09-Package_Tiendas.log
PROMPT Creando Package Tiendas... 

/************************************************************************************************************************
* Nombre......: PK_TIENDAS                                                                                              *
* Descripcin.: Agrupa la gestin de tiendas.                                                                           *
*************************************************************************************************************************/
 
CREATE OR REPLACE PACKAGE UOC.PK_TIENDAS AS

PROCEDURE usp_insertar_tienda (

  I_Nombre       IN Tienda.V_Nombre%Type,
  I_Ciudad       IN Ciudad.I_Ciudad%Type,
  I_Region       IN Region.I_Region%Type,
  I_Email        IN Tienda.V_Email%Type,
  I_Trabajadores IN Tienda.N_Trabajadores%Type,
  I_Franquicia   IN Tienda.V_Franquicia%Type,
  I_Virtual      IN Tienda.V_Virtual%Type,
  O_RSP          OUT NOCOPY VARCHAR2

  );

PROCEDURE usp_actualizar_tienda (

  I_Tienda       IN Tienda.I_Tienda%Type,
  I_Nombre       IN Tienda.V_Nombre%Type,
  I_Ciudad       IN Ciudad.I_Ciudad%Type,
  I_Region       IN Region.I_Region%Type,
  I_Email        IN Tienda.V_Email%Type,
  I_Trabajadores IN Tienda.N_Trabajadores%Type,
  I_Franquicia   IN Tienda.V_Franquicia%Type,
  I_Virtual      IN Tienda.V_Virtual%Type,
  O_RSP          OUT NOCOPY VARCHAR2

  );
  
PROCEDURE usp_eliminar_tienda (

  I_Tienda       IN Tienda.I_Tienda%Type,
  O_RSP          OUT NOCOPY VARCHAR2

  );

END PK_TIENDAS;

/

CREATE OR REPLACE PACKAGE BODY UOC.PK_TIENDAS AS

/****************************************************************************************************************************************
*                                                                                                                                       * 
* Nombre........: usp_insertar_tienda                                                                                                   *
* Descripcin...: Permite aadir un nueva tienda.                                                                                       *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Nombre       (Nombre de la tienda                                     ) - VARCHAR2(250 CHAR) - Obligatorio *
*                          I_Ciudad       (Cdigo de la ciudad en la que est ubicada              ) - Integer            - Obligatorio *
*                          I_Region       (Cdigo de la comunidad autonoma a la que pertenece      ) - Integer            - Obligatorio *
*                          I_Email 		  (E_mail del gerente                                      ) - VARCHAR2(250 CHAR) - Obligatorio *
*                          I_Trabajadores (Nmero de trabajadores - Valores: mayor de cero         ) - NUMBER(5)          - Obligatorio *
*                          I_Franquicia   (Indica si se trata de una franquicia - Valores S/N      ) - VARCHAR2(1 CHAR)   - Obligatorio *
*                          I_Virtual      (Indica si se trata de una tienda virtual - Valores: S/N ) - VARCHAR2(1 CHAR)   - Obligatorio *
*                 OUTPUT.: O_RSP          (Resultado de la ejecucin                               ) - VARCHAR2                         *
*                                                                                                                                       *
* Precondicin..: No existe la tienda.                                                                                                  *
* Postcondicin.: Se incorpora la nueva tienda a la tabla.                                                                              *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 OK - El alta se realiz correctamente.                                                                                *
*                 ERROR: No se informa el nombre de la tienda.                                                                          *
*                 ERROR: No se informa la ciudad en la que est ubicada la tienda.                                                      *
*                 ERROR: No se informa la regin en la que est ubicada la tienda.                                                      *
*                 ERROR: No se informa el e-mail del gerente de la tienda.                                                              *
*                 ERROR: El e-mail informado no es correcto.                                                                            *
*                 ERROR: No se informa el nmero de trabajadores de la tienda.                                                          *
*                 ERROR: El nmero de trabajadores debe ser un valor numrico                                                           *
*                 ERROR: No se informa correctamente si la tienda es una franquicia.                                                    *
*                 ERROR: No se informa correctamente si la tienda es virtual.                                                           *
*                 ERROR: El nombre informado est asociado a otra tienda.                                                               *
*                 ERROR: La ciudad informada no existe.                                                                                 *
*                 ERROR: La ciudad informada est anulada.                                                                              *
*                 ERROR: La regin informada no existe.                                                                                 *
*                 ERROR: La regin informada est anulada.                                                                              *
*                 ERROR: El e-mail informado no es correcto.                                                                            *
*                 ERROR: El nmero de trabajadores informado no es correcto.                                                            *
*                 ERROR: La tienda ya existe.                                                                                           *
*                 ERROR: El pas de la ciudad y la regin no es coincidente.      	                                                    *
*                 ERROR: SQLCODE - SQLERRM                                                                                              *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_insertar_tienda (

  I_Nombre           IN Tienda.V_Nombre%Type,
  I_Ciudad           IN Ciudad.I_Ciudad%Type,
  I_Region           IN Region.I_Region%Type,
  I_Email            IN Tienda.V_Email%Type,
  I_Trabajadores     IN Tienda.N_Trabajadores%Type,
  I_Franquicia       IN Tienda.V_Franquicia%Type,
  I_Virtual          IN Tienda.V_Virtual%Type,
  O_RSP              OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento      VARCHAR2(50 CHAR);
  Parametros_entrada VARCHAR2(1000 CHAR);
  
  Err_Codigo         NUMBER;
  Err_Descripcion    VARCHAR2(200 CHAR);
	
  Ex_Trabajadores    EXCEPTION;
  Ex_Franquicia      EXCEPTION;
  Ex_Virtual	     EXCEPTION;

BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_TIENDAS.usp_insertar_tienda';
  Parametros_entrada  := '(' || I_Nombre       || ', ' || I_Ciudad     || ', '
                             || I_Region       || ', ' || I_Email      || ', '
                             || I_Trabajadores || ', ' || I_Franquicia || ', '
                             || I_Virtual      || ')';
  O_RSP               := 'OK';
  
  -- Verificacin de datos
  
  IF (I_Trabajadores IS NULL) THEN
    RAISE Ex_Trabajadores;
  END IF;

  IF (I_Franquicia IS NULL or TRIM(I_Franquicia) IS NULL or
      (I_Franquicia <> 'S' and I_Franquicia <> 'N')) THEN
    RAISE Ex_Franquicia;
  END IF;
  
  IF (I_Virtual IS NULL or TRIM(I_Virtual) IS NULL or
      (I_Virtual <> 'S' and I_Virtual <> 'N')) THEN
    RAISE Ex_Virtual;
  END IF;
  
  PK_VERIFICACION.usp_verificar_nombre(NULL, I_Nombre, O_RSP);
  
  IF (O_RSP = 'OK') THEN
	PK_VERIFICACION.usp_verificar_ciudad(I_Ciudad, O_RSP);
  END IF;
  
  IF (O_RSP = 'OK') THEN
  	PK_VERIFICACION.usp_verificar_region(I_Region, O_RSP);
  END IF;
  
  IF (O_RSP = 'OK') THEN
  	PK_VERIFICACION.usp_verificar_ubicacion(I_Region, I_Ciudad, O_RSP);
  END IF;
  
  IF (O_RSP = 'OK') THEN
	PK_VERIFICACION.usp_verificar_email(I_Email, O_RSP);
  END IF;
  
  IF (O_RSP = 'OK') THEN
	PK_VERIFICACION.usp_verificar_trabajadores(I_Trabajadores, O_RSP);
  END IF;
  
  IF (O_RSP = 'OK') THEN
  
    -- Alta del registro
    
    INSERT INTO TIENDA	T 
      (T.V_NOMBRE, T.I_CIUDAD, T.I_REGION, T.V_EMAIL, T.N_TRABAJADORES, T.V_FRANQUICIA, T.V_VIRTUAL, T.F_ALTA)
      VALUES (I_Nombre, I_Ciudad, I_Region, I_Email, I_Trabajadores, I_Franquicia, I_Virtual, SYSTIMESTAMP);
  
  END IF;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
   
  EXCEPTION

    WHEN Ex_Trabajadores THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_TIENDAS.usp_insertar_tienda',1));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
  
    WHEN Ex_Franquicia THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_TIENDAS.usp_insertar_tienda',2));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
  
	WHEN Ex_Virtual THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_TIENDAS.usp_insertar_tienda',3));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
	  
    WHEN DUP_VAL_ON_INDEX THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_TIENDAS.usp_insertar_tienda',4));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);			
          
    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_insertar_tienda;

/****************************************************************************************************************************************
*                                                                                                                                       *
* Nombre........: usp_actualizar_tienda                                                                                                 *
* Descripcin...: Permite actualizar la informacin de una tienda.                                                                      *
*                 Los campos opcionales puede estar informados o ser NULL                                                               *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Tienda       (Cdigo de identificacin de la tienda                   ) - Integer            - Obligatorio *
*                          I_Nombre       (Nombre de la tienda                                     ) - VARCHAR2(250 CHAR) - Opcional    *
*                          I_Ciudad       (Cdigo de la ciudad en la que est ubicada              ) - Integer            - Opcional    *
*                          I_Region       (Cdigo de la comunidad autonoma a la que pertenece      ) - Integer            - Opcional    *
*                          I_Email 		  (E_mail del gerente                                      ) - VARCHAR2(250 CHAR) - Opcional    *
*                          I_Trabajadores (Nmero de trabajadores - Valores: mayor de cero         ) - NUMBER(5)          - Opcional    *
*                          I_Franquicia   (Indica si se trata de una franquicia - Valores S/N      ) - VARCHAR2(1 CHAR)   - Opcional    *
*                          I_Virtual      (Indica si se trata de una tienda virtual - Valores: S/N ) - VARCHAR2(1 CHAR)   - Opcional    *
*                 OUTPUT.: O_RSP          (Resultado de la ejecucin                               ) - VARCHAR2                         *
*                                                                                                                                       *
* Precondicin..: Existe la tienda a modificar.                                                                                         *
* Postcondicin.: Se actualizan los datos correspondientes a la tienda.                                                                 *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 OK - La modificacin se realiz correctamente.                                                                        *
*                 ERROR: No se informa el cdigo de identificacin de la tienda.                                                        *
*                 ERROR: No existe la tienda a modificar.                                                                               *
*                 ERROR: No se informa correctamente si la tienda es una franquicia.                                                    *
*                 ERROR: No se informa correctamente si la tienda es virtual.                                                           *
*                 ERROR: El nombre informado est asociado a otra tienda.                                                               *
*                 ERROR: La ciudad informada no existe.                                                                                 *
*                 ERROR: La ciudad informada est anulada.                                                                              *
*                 ERROR: La regin informada no es correcta.                                                                            *
*                 ERROR: El e-mail informado no es correcto.                                                                            *
*                 ERROR: El nmero de trabajadores informado no es correcto.                                                            *
*                 ERROR: El pas de la ciudad y la regin no es coincidente.      	                                                    *
*                 ERROR: SQLCODE - SQLERRM                                                                                              *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_actualizar_tienda (

  I_Tienda           IN Tienda.I_Tienda%Type,
  I_Nombre           IN Tienda.V_Nombre%Type,
  I_Ciudad           IN Ciudad.I_Ciudad%Type,
  I_Region           IN Region.I_Region%Type,
  I_Email            IN Tienda.V_Email%Type,
  I_Trabajadores     IN Tienda.N_Trabajadores%Type,
  I_Franquicia       IN Tienda.V_Franquicia%Type,
  I_Virtual          IN Tienda.V_Virtual%Type,
  O_RSP              OUT NOCOPY VARCHAR2
  
  )

IS
  
  Procedimiento      VARCHAR2(50 CHAR);
  Parametros_entrada VARCHAR2(1000 CHAR);
  
  Registros          NUMBER;
  IN_Tienda          INTEGER;
  
  Err_Codigo         NUMBER;
  Err_Descripcion    VARCHAR2(200 CHAR);
	
  Ex_Tienda          EXCEPTION;
  Ex_Franquicia      EXCEPTION;
  Ex_Virtual	     EXCEPTION;
  Ex_Registros       EXCEPTION;

  -- Guardan los valores previos a la actualizacin
  
  TMP_Nombre         Tienda.V_Nombre%Type;
  TMP_Ciudad         Ciudad.I_Ciudad%Type;
  TMP_Region         Region.I_Region%Type;
  TMP_Email          Tienda.V_Email%Type;
  TMP_Trabajadores   Tienda.N_Trabajadores%Type;
  TMP_Franquicia     Tienda.V_Franquicia%Type;
  TMP_Virtual        Tienda.V_Virtual%Type;

BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_TIENDAS.usp_actualizar_tienda';
  Parametros_entrada  := '(' || I_Tienda      || ', ' || I_Nombre         || ', ' 
                             || I_Ciudad      || ', ' || I_Region       || ', ' 
							 || I_Email       || ', ' || I_Trabajadores || ', ' 
							 || I_Franquicia  || ', ' || I_Virtual      || ')';
  O_RSP               := 'OK';
  IN_Tienda           := I_Tienda;
  
  -- Verifica que est informado el cdigo de identificacin de la tienda
  
  IF (I_Tienda IS NULL) THEN
    RAISE Ex_Tienda;
  END IF;
  
  -- Verifica la existencia y en caso afirmativo recupera la informacin de la tienda
  
  SELECT COUNT(*) INTO Registros FROM TIENDA T
    WHERE T.I_TIENDA = IN_Tienda;
  
  IF (Registros = 0) THEN
	RAISE Ex_Registros;
  END IF;
  
  SELECT V_Nombre, I_Ciudad, I_Region, V_Email, N_Trabajadores, V_Franquicia, V_Virtual INTO
    TMP_Nombre, TMP_Ciudad, TMP_Region, TMP_Email, TMP_Trabajadores, TMP_Franquicia, TMP_Virtual
  FROM Tienda T
  WHERE T.I_Tienda = IN_Tienda;
      
  -- Verificacin de los datos recibidos
  
  IF (I_Franquicia IS NOT NULL) THEN
	IF (I_Franquicia <> 'S' and I_Franquicia <> 'N') THEN
		RAISE Ex_Franquicia;
	END IF;
	
	TMP_Franquicia := I_Franquicia;
  
  END IF;	
  
  IF (I_Virtual IS NOT NULL) THEN
	
	IF (I_Virtual <> 'S' and I_Virtual <> 'N') THEN
		RAISE Ex_Virtual;
	END IF;
	
	TMP_Virtual := I_Virtual;
  
  END IF;	
  
  IF (I_Nombre IS NOT NULL or TRIM(I_Nombre) IS NOT NULL) THEN
	
	PK_VERIFICACION.usp_verificar_nombre(I_Tienda, I_Nombre, O_RSP);
	
	IF (O_RSP = 'OK') THEN 
		TMP_Nombre := I_Nombre;
	END IF;
  
  END IF;
  
  IF (O_RSP = 'OK' and I_Ciudad IS NOT NULL) THEN
	
	PK_VERIFICACION.usp_verificar_ciudad(I_Ciudad, O_RSP);
  
	IF (O_RSP = 'OK') THEN 
		TMP_Ciudad := I_Ciudad;
	END IF;
	
  END IF;
  
  IF (O_RSP = 'OK' and I_Region IS NOT NULL) THEN
  	
	PK_VERIFICACION.usp_verificar_region(I_Region, O_RSP);
	
	IF (O_RSP = 'OK') THEN 
		TMP_Region := I_Region;
	END IF;
	
  END IF;
  
  IF (O_RSP = 'OK') THEN
	IF (I_Email IS NOT NULL or TRIM(I_Email) IS NOT NULL) THEN
	
		PK_VERIFICACION.usp_verificar_email(I_Email, O_RSP);
	
		IF (O_RSP = 'OK') THEN 
			TMP_Email := I_Email;
		END IF;
		
	END IF;
  END IF;
  
  IF (O_RSP = 'OK' and I_Trabajadores IS NOT NULL) THEN
	
	PK_VERIFICACION.usp_verificar_trabajadores(I_Trabajadores, O_RSP);
	
	IF (O_RSP = 'OK') THEN 
		TMP_Trabajadores := I_Trabajadores;
	END IF;
	
  END IF;
  
  IF (O_RSP = 'OK') THEN
  	PK_VERIFICACION.usp_verificar_ubicacion(TMP_Region, TMP_Ciudad, O_RSP);
  END IF;
  
  IF (O_RSP = 'OK') THEN
  
    -- Actualizacin del registro (si est eliminado lgicamente lo activa)
    
    UPDATE TIENDA T SET 
	  T.V_NOMBRE       = TMP_Nombre,
	  T.I_CIUDAD       = TMP_Ciudad,
      T.I_REGION       = TMP_Region,
      T.V_EMAIL        = TMP_Email,
      T.N_TRABAJADORES = TMP_Trabajadores,
	  T.V_FRANQUICIA   = TMP_Franquicia,
	  T.V_VIRTUAL      = TMP_Virtual,
      T.F_MODIFICACION = SYSTIMESTAMP,
      T.F_ELIMINACION  = NULL
      WHERE T.I_Tienda = I_Tienda;
  
    IF SQL%NOTFOUND THEN
      RAISE NO_DATA_FOUND;
    END IF;
    
  END IF;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
  
  EXCEPTION

    WHEN NO_DATA_FOUND THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_TIENDAS.usp_actualizar_tienda',1));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				

    WHEN Ex_Tienda THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_TIENDAS.usp_actualizar_tienda',2));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
	 
	WHEN Ex_Franquicia THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_TIENDAS.usp_actualizar_tienda',3));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
  
	WHEN Ex_Virtual THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_TIENDAS.usp_actualizar_tienda',4));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
	 
	WHEN Ex_Registros THEN
	  O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_TIENDAS.usp_actualizar_tienda',5));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
	  
    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_actualizar_tienda;

/****************************************************************************************************************************************
*                                                                                                                                       *
* Nombre........: usp_eliminar_tienda                                                                                                   *
* Descripcin...: Permite eliminar una tienda.                                                                                          *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Tienda (Cdigo de identificacin de la tienda ) - Integer  - Obligatorio                                   *
*                 OUTPUT.: O_RSP    (Resultado de la ejecucin             ) - VARCHAR2                                                 *
*                                                                                                                                       *
* Precondicin..: Existe la tienda a eliminar.                                                                                          *
* Postcondicin.: Se realiza la eliminacin fsica o lgica de la tienda.                                                               *
*                                                                                                                                       *
* Resultado de la ejecucin:                                                                                                            *
*                                                                                                                                       *
*                 OK - La eliminacin se realiz correctamente.                                                                         *
*                 ERROR: No se informa el cdigo de identificacin de la tienda.                                                        *
*                 ERROR: La tienda informada no existe.                                                                                 *
*                 ERROR: La tienda informada est anulada                                                                               *
*                 ERROR: SQLCODE - SQLERRM                                                                                              *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_eliminar_tienda (

  I_Tienda IN Tienda.I_Tienda%Type,
  O_RSP    OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento      VARCHAR2(50 CHAR);
  Parametros_entrada VARCHAR2(1000 CHAR);
  
  Err_Codigo         NUMBER;
  Err_Descripcion    VARCHAR2(200 CHAR);
	
BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_TIENDAS.usp_eliminar_tienda';
  Parametros_entrada  := '(' || I_Tienda || ')';
  O_RSP               := 'OK';
  
  -- Verificacin de datos
  
  PK_VERIFICACION.usp_verificar_tienda(I_Tienda, O_RSP);
  
  IF (O_RSP = 'OK') then
  
    -- Elimina la tienda fsica o lgicamente.
  
    BEGIN
  
      DELETE FROM TIENDA T WHERE T.I_TIENDA = I_Tienda;
    
      EXCEPTION
  
        WHEN OTHERS THEN
    
          BEGIN
          
            UPDATE TIENDA T
            SET    T.F_ELIMINACION = SYSTIMESTAMP
            WHERE  T.I_TIENDA = I_Tienda;
          
          EXCEPTION
          
            WHEN OTHERS THEN
              Err_Codigo      := SQLCODE;
              Err_Descripcion := SQLERRM;
      
              O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                           || '-' 
                                           || Err_Descripcion;
      
              PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
              
          END;
    
    END;
    
  END IF;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
  
  EXCEPTION

    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_eliminar_tienda;

END PK_TIENDAS;

/

SPOOL OFF;
