SPOOL .\Logs\11-Package_Hechos.log
PROMPT Creando Package Hechos... 

/************************************************************************************************************************
* Nombre......: PK_HECHOS                                                                                               *
* Descripcin.: Agrupa la gestin de hechos.                                                                            *
*************************************************************************************************************************/
 
CREATE OR REPLACE PACKAGE UOC.PK_HECHOS AS

PROCEDURE usp_insertar_hecho (

  I_Tienda          IN Hecho.I_Tienda%Type,
  I_Producto        IN Hecho.N_Producto%Type,
  I_Fecha           IN Date,
  I_Hora            IN Hecho.N_Hora%Type,
  I_Cantidad_Ventas IN Hecho.I_Cantidad_Ventas%Type,
  I_Precio_Bruto    IN Hecho.N_Precio_Bruto%Type,
  I_Beneficio_Neto  IN Hecho.N_Beneficio_Neto%Type,
  O_RSP             OUT NOCOPY VARCHAR2

  );

PROCEDURE usp_actualizar_hecho (

  I_Tienda          IN Hecho.I_Tienda%Type,
  I_Producto        IN Hecho.N_Producto%Type,
  I_Fecha           IN Date,
  I_Hora            IN Hecho.N_Hora%Type,
  I_Cantidad_Ventas IN Hecho.I_Cantidad_Ventas%Type,
  I_Precio_Bruto    IN Hecho.N_Precio_Bruto%Type,
  I_Beneficio_Neto  IN Hecho.N_Beneficio_Neto%Type,
  O_RSP             OUT NOCOPY VARCHAR2

  );
  
PROCEDURE usp_eliminar_hecho (

  I_Tienda          IN Hecho.I_Tienda%Type,
  I_Producto        IN Hecho.N_Producto%Type,
  I_Fecha           IN Date,
  I_Hora            IN Hecho.N_Hora%Type,
  O_RSP             OUT NOCOPY VARCHAR2

  );

END PK_HECHOS;

/

CREATE OR REPLACE PACKAGE BODY UOC.PK_HECHOS AS

/***********************************************************************************************************************************************
*                                                                                                                                              * 
* Nombre........: usp_insertar_hecho                                                                                                           *
* Descripcin...: Permite aadir un nuevo registro con la informacin de la venta diaria.                                                      *
*                                                                                                                                              *
* Parmetros....: INPUT..: I_Tienda          (Cdigo de identificacin de la tienda                             ) - Integer      - Obligatorio *
*                          I_Producto        (Cdigo de identificacin del producto                             ) - Number(13)   - Obligatorio *
*                          I_Fecha           (Fecha en la que se realizaron las ventas                          ) - Date         - Obligatorio *
*                          I_Hora            (Hora en la que se realiz la venta                                ) - Number(2)    - Obligatorio *
*                          I_Cantidad_Ventas (Cantidad total del producto vendida durante el da/hora           ) - Integer      - Obligatorio *
*                          I_Precio_Bruto    (Precio bruto total de los productos vendidos durante el da/hora  ) - Number(12,3) - Obligatorio *
*                          I_Beneficio_Neto  (Beneficio neto total de los productos vendidos durante el da/hora) - Number(12,3) - Obligatorio *
*                 OUTPUT.: O_RSP             (Resultado de la ejecucin                                         ) - Varchar2                   *
*                                                                                                                                              *
* Precondicin..: No existe el registro correspondiente a la venta.                                                                            *
* Postcondicin.: Se incorpora la informacin de la venta diaria.                                                                              *
*                                                                                                                                              *
* Resultado de la ejecucin:                                                                                                                   *
*                                                                                                                                              *
*                 OK - El alta se realiz correctamente.                                                                                       *
*                 ERROR: Las ventas diarias ya existen en la tabla                                                                             *
*                 ERROR: SQLCODE - SQLERRM                                                                                                     *
*                                                                                                                                              *
************************************************************************************************************************************************/

PROCEDURE usp_insertar_hecho (

  I_Tienda          IN Hecho.I_Tienda%Type,
  I_Producto        IN Hecho.N_Producto%Type,
  I_Fecha           IN Date,
  I_Hora            IN Hecho.N_Hora%Type,
  I_Cantidad_Ventas IN Hecho.I_Cantidad_Ventas%Type,
  I_Precio_Bruto    IN Hecho.N_Precio_Bruto%Type,
  I_Beneficio_Neto  IN Hecho.N_Beneficio_Neto%Type,
  O_RSP             OUT NOCOPY VARCHAR2

  )

IS
  
  Procedimiento      VARCHAR2(50 CHAR);
  Parametros_entrada VARCHAR2(1000 CHAR);

  I_Tiempo           INTEGER;
  IN_Tiempo          INTEGER;  
  I_Anyo             NUMBER(4);
  
  Err_Codigo         NUMBER;
  Err_Descripcion    VARCHAR2(200 CHAR);
  
  Ex_Fecha_Posterior EXCEPTION;
  
BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_HECHOS.usp_insertar_hecho';
  Parametros_entrada  := '(' || I_Tienda           || ', ' || I_Producto     || ', '
                             || I_Fecha            || ', ' || I_Hora         || ', '
                             || I_Cantidad_Ventas  || ', ' || I_Precio_Bruto || ', '
                             || I_Beneficio_Neto   || ')';
  O_RSP               := 'OK';
  
  -- Verificacin de datos
  
  PK_VERIFICACION.usp_verificar_tienda(I_Tienda, O_RSP);
   
  IF (O_RSP = 'OK') THEN
	PK_VERIFICACION.usp_verificar_producto(I_Producto, 'A', O_RSP);
  END IF;
  
  IF (O_RSP = 'OK') THEN
   	--PK_VERIFICACION.usp_verificar_tiempo(TO_CHAR(I_Fecha,'dd/mm/yyyy'), O_RSP);
	PK_VERIFICACION.usp_verificar_tiempo(I_Fecha, O_RSP);
  END IF;
  
  IF (O_RSP = 'OK') THEN 
    IF I_Fecha > current_timestamp THEN  
	  RAISE Ex_Fecha_Posterior;
	END IF;  
  END IF; 
  
  IF (O_RSP = 'OK') THEN
  	PK_VERIFICACION.usp_verificar_hora(I_Hora, O_RSP);
  END IF;
  
  IF (O_RSP = 'OK') THEN
	PK_VERIFICACION.usp_verificar_cantidad_ventas(I_Cantidad_Ventas, O_RSP);
  END IF;
  
  IF (O_RSP = 'OK') THEN
	PK_VERIFICACION.usp_verificar_precio_bruto(I_Precio_Bruto, O_RSP);
  END IF;
  
  IF (O_RSP = 'OK') THEN
	PK_VERIFICACION.usp_verificar_beneficio_neto(I_Beneficio_Neto, O_RSP);
  END IF;
  
  IF (O_RSP = 'OK') THEN

	-- Recupera el identificador de tiempo asociado a la fecha informada.
	
	I_Tiempo  := PK_FUNCIONES.f_tiempo(I_Fecha);
	
	-- Si no existe, inserta la fecha recibida en la tabla TIEMPO
	
	IF (I_Tiempo = 0) THEN
	  PK_PROCEDIMIENTOS.usp_insertar_tiempo(I_Fecha, I_Tiempo); 
	END IF;
	
    -- Alta del registro
	
    INSERT INTO HECHO H 
      (H.I_TIENDA, H.N_PRODUCTO, H.I_TIEMPO, H.N_HORA, H.I_CANTIDAD_VENTAS, H.N_PRECIO_BRUTO, H.N_BENEFICIO_NETO, H.F_ALTA)
      VALUES (I_Tienda, I_Producto, I_Tiempo, I_Hora, I_Cantidad_Ventas, I_Precio_Bruto, I_Beneficio_Neto, SYSTIMESTAMP);

	IN_Tiempo := I_Tiempo;
	
	SELECT N_ANYO INTO I_Anyo 
		FROM TIEMPO 
		WHERE I_TIEMPO = IN_Tiempo;
	
	PK_HISTORICOS.usp_actualizar_historico(I_Anyo);	
	PK_HISTORICOS.usp_actualizar_historico(NULL);	
	
  END IF;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
   
  EXCEPTION

    WHEN DUP_VAL_ON_INDEX THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_HECHOS.usp_insertar_hecho',1));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);			
    
    WHEN Ex_Fecha_Posterior THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_HECHOS.usp_insertar_hecho',2));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);			
	
    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_insertar_hecho;

/***********************************************************************************************************************************************
*                                                                                                                                              *
* Nombre........: usp_actualizar_hecho                                                                                                         *
* Descripcin...: Permite aadir un nuevo registro con la informacin de la venta diaria.                                                      *
*                                                                                                                                              *
* Parmetros....: INPUT..: I_Tienda          (Cdigo de identificacin de la tienda                             ) - Integer      - Obligatorio *
*                          I_Producto        (Cdigo de identificacin del producto                             ) - Number(13)   - Obligatorio *
*                          I_Fecha           (Fecha en la que se realizaron las ventas                          ) - Date         - Obligatorio *
*                          I_Hora            (Hora en la que se realiz la venta                                ) - Number(2)    - Obligatorio *
*                          I_Cantidad_Ventas (Cantidad total del producto vendida durante el da/hora           ) - Integer      - Opcional    *
*                          I_Precio_Bruto    (Precio bruto total de los productos vendidos durante el da/hora  ) - Number(12,3) - Opcional    *
*                          I_Beneficio_Neto  (Beneficio neto total de los productos vendidos durante el da/hora) - Number(12,3) - Opcional    *
*                 OUTPUT.: O_RSP             (Resultado de la ejecucin                                         ) - Varchar2                   *
*                                                                                                                                              *
* Precondicin..: Existe el registro correspondiente a la venta.                                                                               *
* Postcondicin.: Se actualizan los datos correspondientes a la venta.                                                                         *
*                                                                                                                                              *
* Resultado de la ejecucin:                                                                                                                   *
*                                                                                                                                              *
*                 OK - La modificacin se realiz correctamente.                                                                               *
*                 ERROR: Los parmetros recibidos no permiten localizar el registro a modificar.                                               *
*                 ERROR: No existe el registro de ventas diarias.                                                                              *
*                 ERROR: SQLCODE - SQLERRM                                                                                                     *
*                                                                                                                                              *
************************************************************************************************************************************************/

PROCEDURE usp_actualizar_hecho (

  I_Tienda          IN Hecho.I_Tienda%Type,
  I_Producto        IN Hecho.N_Producto%Type,
  I_Fecha           IN Date,
  I_Hora            IN Hecho.N_Hora%Type,
  I_Cantidad_Ventas IN Hecho.I_Cantidad_Ventas%Type,
  I_Precio_Bruto    IN Hecho.N_Precio_Bruto%Type,
  I_Beneficio_Neto  IN Hecho.N_Beneficio_Neto%Type,
  O_RSP             OUT NOCOPY VARCHAR2
  
  )

IS
  
  Procedimiento      VARCHAR2(50 CHAR);
  Parametros_entrada VARCHAR2(1000 CHAR);
  
  I_Tiempo           INTEGER;
  Registros          NUMBER;
  I_Anyo             NUMBER(4);
  
  Err_Codigo         NUMBER;
  Err_Descripcion    VARCHAR2(200 CHAR);
  
  Ex_Busqueda        EXCEPTION;
  Ex_Registros		 EXCEPTION;
  
  -- Guardan los valores previos a la actualizacin

  TMP_Tienda          Hecho.I_Tienda%Type;
  TMP_Producto        Hecho.N_Producto%Type;
  TMP_Tiempo          Hecho.I_Tiempo%Type;
  TMP_Hora            Hecho.N_Hora%Type;
  TMP_Cantidad_Ventas Hecho.I_Cantidad_Ventas%Type;
  TMP_Precio_Bruto    Hecho.N_Precio_Bruto%Type;
  TMP_Beneficio_Neto  Hecho.N_Beneficio_Neto%Type;
    
BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_HECHOS.usp_actualizar_hecho';
  Parametros_entrada  := '(' || I_Tienda          || ', ' || I_Producto     || ', '
                             || I_Fecha           || ', ' || I_Hora         || ', '
                             || I_Cantidad_Ventas || ', ' || I_Precio_Bruto || ', '
                             || I_Beneficio_Neto  || ')';
  O_RSP               := 'OK';
  
  -- Verifica que sean correctos los campos que forman la clave de la entidad
  
  IF (I_Tienda IS NULL or I_Producto IS NULL or I_Fecha IS NULL or I_Hora IS NULL) THEN
    RAISE Ex_Busqueda;
  END IF;

  PK_VERIFICACION.usp_verificar_tienda(I_Tienda, O_RSP);
    
  IF (O_RSP = 'OK') THEN
	PK_VERIFICACION.usp_verificar_producto(I_Producto, 'E', O_RSP);
  END IF;
  
  IF (O_RSP = 'OK') THEN
  	PK_VERIFICACION.usp_verificar_tiempo(TO_CHAR(I_Fecha,'dd/mm/yyyy'), O_RSP);
  END IF;
  
  IF (O_RSP = 'OK') THEN
  	PK_VERIFICACION.usp_verificar_hora(I_Hora, O_RSP);
  END IF;
  
  -- Recupera el identificador de tiempo asociado a la fecha informada.
  
  I_Tiempo := PK_FUNCIONES.f_tiempo(I_Fecha);
  
  -- Verifica la existencia y en caso afirmativo recupera la informacin de la tienda
  
  SELECT COUNT(*) INTO Registros FROM HECHO H
     WHERE H.I_Tienda = I_Tienda and H.N_Producto = I_Producto and H.I_Tiempo = I_Tiempo and H.N_Hora = I_Hora;
  
  IF (Registros = 0) THEN
	RAISE Ex_Registros;
  END IF;
  
  SELECT H.I_Tienda, H.N_Producto, H.I_Tiempo, H.N_Hora, H.I_Cantidad_ventas, H.N_Precio_bruto, H.N_Beneficio_neto INTO
    TMP_Tienda, TMP_Producto, TMP_Tiempo, TMP_Hora, TMP_Cantidad_Ventas, TMP_Precio_Bruto, TMP_Beneficio_Neto
  FROM HECHO H
  WHERE H.I_Tienda = I_Tienda and H.N_Producto = I_Producto and H.I_Tiempo = I_Tiempo and H.N_Hora = I_Hora;
  
  -- Verificacin de los datos recibidos
  
  IF (I_Cantidad_Ventas IS NOT NULL) THEN
	
	PK_VERIFICACION.usp_verificar_cantidad_ventas(I_Cantidad_Ventas, O_RSP);
	
	IF (O_RSP = 'OK') THEN 
		TMP_Cantidad_Ventas := I_Cantidad_Ventas;
    END IF;
	
  END IF;	
  
  IF (O_RSP = 'OK' and I_Precio_Bruto IS NOT NULL) THEN
	
	PK_VERIFICACION.usp_verificar_precio_bruto(I_Precio_Bruto, O_RSP);
  
	IF (O_RSP = 'OK') THEN 
		TMP_Precio_Bruto := I_Precio_Bruto;
	END IF;
	
  END IF;
  
  IF (O_RSP = 'OK' and I_Beneficio_Neto IS NOT NULL) THEN
	
	PK_VERIFICACION.usp_verificar_beneficio_neto(I_Beneficio_Neto, O_RSP);
  
	IF (O_RSP = 'OK') THEN 
		TMP_Beneficio_Neto := I_Beneficio_Neto;
	END IF;
	
  END IF;
  
  IF (O_RSP = 'OK') THEN
  
    -- Actualizacin del registro (si est eliminado lgicamente lo activa)
    
    UPDATE HECHO H SET 
	  H.I_TIENDA          = TMP_Tienda,
	  H.N_PRODUCTO        = TMP_Producto,
      H.I_TIEMPO          = TMP_Tiempo,
      H.N_HORA            = TMP_Hora,
      H.I_CANTIDAD_VENTAS = TMP_Cantidad_Ventas,
	  H.N_PRECIO_BRUTO    = TMP_Precio_Bruto,
	  H.N_BENEFICIO_NETO  = TMP_Beneficio_Neto,
      H.F_MODIFICACION    = SYSTIMESTAMP 
      WHERE H.I_Tienda    = TMP_Tienda and H.N_Producto = TMP_Producto and H.I_Tiempo = TMP_Tiempo and H.N_Hora = TMP_Hora;
  
    IF SQL%NOTFOUND THEN
       RAISE NO_DATA_FOUND;
    END IF;
	
    SELECT N_ANYO INTO I_Anyo 
		FROM TIEMPO 
		WHERE I_TIEMPO = TMP_Tiempo;
	
	PK_HISTORICOS.usp_actualizar_historico(I_Anyo);	
	PK_HISTORICOS.usp_actualizar_historico(NULL);	
    
  END IF;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
  
  EXCEPTION

    WHEN NO_DATA_FOUND THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_HECHOS.usp_actualizar_hecho',1));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				

    WHEN Ex_Busqueda THEN
      O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_HECHOS.usp_actualizar_hecho',2));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
	 
	WHEN Ex_Registros THEN
	  O_RSP := TRIM(PK_FUNCIONES.f_mensaje('PK_HECHOS.usp_actualizar_hecho',3));
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);				
	  
    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_actualizar_hecho;

/************************************************************************************************************************************************
*                                                                                                                                               *
* Nombre........: usp_eliminar_hecho                                                                                                            *
* Descripcin...: Permite eliminar la informacin de ventas asociada a un da/hora.                                                             *
*                                                                                                                                               *
* Parmetros....: INPUT..: I_Tienda   (Cdigo de identificacin de la tienda   ) - Integer      - Obligatorio                                   *
*                          I_Producto (Cdigo de identificacin del producto   ) - Number(13)   - Obligatorio                                   *
*                          I_Fecha    (Fecha en la que se realizaron las ventas) - Date         - Obligatorio                                   *
*                          I_Hora     (Hora en la que se realiz la venta      ) - Number(2)    - Obligatorio                                   *
*                 OUTPUT.: O_RSP      (Resultado de la ejecucin               ) - VARCHAR2                                                     *
*                                                                                                                                               *
* Precondicin..: Existe el registro correspondiente a la venta.                                                                                *
* Postcondicin.: Se realiza la eliminacin de la venta.                                                                                        *
*                                                                                                                                               *
* Resultado de la ejecucin:                                                                                                                    *
*                                                                                                                                               *
*                 OK - La eliminacin se realiz correctamente.                                                                                 *
*                 ERROR: SQLCODE - SQLERRM                                                                                                      *
*                                                                                                                                               *
*************************************************************************************************************************************************/

PROCEDURE usp_eliminar_hecho (

  I_Tienda   IN Hecho.I_Tienda%Type,
  I_Producto IN Hecho.N_Producto%Type,
  I_Fecha    IN Date,
  I_Hora     IN Hecho.N_Hora%Type,
  O_RSP      OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento      VARCHAR2(50 CHAR);
  Parametros_entrada VARCHAR2(1000 CHAR);
  
  Registros          INTEGER;
  
  I_Tiempo           INTEGER;
  IN_Tiempo          INTEGER;
  I_Anyo             NUMBER(4);
  
  Err_Codigo         NUMBER;
  Err_Descripcion    VARCHAR2(200 CHAR);
	
BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_HECHOS.usp_eliminar_hecho';
  Parametros_entrada  := '(' || I_Tienda  || ', ' || I_Producto || ', '
                             || I_Fecha   || ', ' || I_Hora     || ')';
  O_RSP               := 'OK';
  
  -- Verificacin de datos
  
  PK_VERIFICACION.usp_verificar_tienda(I_Tienda, O_RSP);
    
  IF (O_RSP = 'OK') THEN
	PK_VERIFICACION.usp_verificar_producto(I_Producto, 'E', O_RSP);
  END IF;
  
  IF (O_RSP = 'OK') THEN
  	PK_VERIFICACION.usp_verificar_tiempo(TO_CHAR(I_Fecha,'dd/mm/yyyy'), O_RSP);
  END IF;
  
  IF (O_RSP = 'OK') THEN
  	PK_VERIFICACION.usp_verificar_hora(I_Hora, O_RSP);
  END IF;
  
  IF (O_RSP = 'OK') then
  
    -- Recupera el identificador de tiempo asociado a la fecha informada.
	
	I_Tiempo  := PK_FUNCIONES.f_tiempo(I_Fecha);
	IN_Tiempo := I_Tiempo;
	
    -- Elimina el registro.
  
    BEGIN
	  
      DELETE FROM HECHO H WHERE H.I_Tienda = I_Tienda and H.N_Producto = I_Producto and H.I_Tiempo = I_Tiempo and H.N_Hora = I_Hora;
    
	  SELECT N_ANYO INTO I_Anyo 
		FROM TIEMPO 
		WHERE I_TIEMPO = IN_Tiempo;
	  
	  -- Verifica si debe eliminar el registro de la tabla.
	  
	  SELECT COUNT(*) INTO REGISTROS
      FROM HECHO H, TIEMPO T
      WHERE H.I_TIEMPO = IN_TIEMPO
      AND T.N_ANYO = I_Anyo;
	  
	  IF (Registros > 0) THEN
	    PK_HISTORICOS.usp_actualizar_historico(I_Anyo);	
	  ELSE
	    DELETE FROM ESTADISTICO WHERE N_ANYO = I_Anyo;
	  END IF;
	  
	  SELECT COUNT(*) INTO REGISTROS
      FROM HECHO;
	  
	  IF (Registros > 0) THEN
	    PK_HISTORICOS.usp_actualizar_historico(NULL);	
	  ELSE 
	    DELETE FROM ESTADISTICO WHERE N_ANYO = 0;
	  END IF;
      
  	  EXCEPTION
  
        WHEN OTHERS THEN
    
			Err_Codigo      := SQLCODE;
            Err_Descripcion := SQLERRM;
      
            O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                         || '-' 
                                         || Err_Descripcion;
      
            PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
    
    END;
    
  END IF;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
  
  EXCEPTION

    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_eliminar_hecho;

END PK_HECHOS;

/

SPOOL OFF;
