SPOOL .\Logs\13-Package_Historicos.log
PROMPT Creando Package Historicos... 

/************************************************************************************************************************
* Nombre......: PK_HISTORICOS                                                                                           *
* Descripcin.: Agrupa la gestin de histricos                                                                         *
*************************************************************************************************************************/
 
CREATE OR REPLACE PACKAGE UOC.PK_HISTORICOS AS

PROCEDURE usp_calcular_beneficio_cadena (

  I_Anyo           IN Estadistico.N_Anyo%Type,
  O_BNeto_Cadena   OUT NOCOPY Estadistico.N_Bneto_Cadena%Type,
  O_RSP            OUT NOCOPY VARCHAR2
  
  );

PROCEDURE usp_calcular_beneficio_tienda (

  I_Anyo           IN Estadistico.N_Anyo%Type,
  O_Tienda         OUT NOCOPY Estadistico.I_Tienda%Type,
  O_BNeto_Tienda   OUT NOCOPY Estadistico.N_Bneto_Tienda%Type,
  O_RSP            OUT NOCOPY VARCHAR2
  
  );
  
PROCEDURE usp_calcular_producto_unidades (

  I_Anyo               IN Estadistico.N_Anyo%Type,
  O_Producto           OUT NOCOPY Estadistico.N_Producto%Type,
  O_Producto_Unidades  OUT NOCOPY Estadistico.I_Producto_Unidades%Type,
  O_RSP                OUT NOCOPY VARCHAR2
  
  );

PROCEDURE usp_calcular_hmas_unidades (

  I_Anyo               IN Estadistico.N_Anyo%Type,
  O_Hora_Mas           OUT NOCOPY Estadistico.N_Hora_Mas%Type,
  O_Hora_Mas_Unidades  OUT NOCOPY Estadistico.I_Hora_Mas_Unidades%Type,
  O_RSP                OUT NOCOPY VARCHAR2
  
  );
  
PROCEDURE usp_calcular_hmenos_unidades (

  I_Anyo                 IN Estadistico.N_Anyo%Type,
  O_Hora_Menos           OUT NOCOPY Estadistico.N_Hora_Menos%Type,
  O_Hora_Menos_Unidades  OUT NOCOPY Estadistico.I_Hora_Menos_Unidades%Type,
  O_RSP                  OUT NOCOPY VARCHAR2
  
  );

PROCEDURE usp_calcular_dmas_unidades (

  I_Anyo              IN Estadistico.N_Anyo%Type,
  O_Dia_Mas           OUT NOCOPY Estadistico.N_Dia_Mas%Type,
  O_Dia_Mas_Unidades  OUT NOCOPY Estadistico.I_Dia_Mas_Unidades%Type,
  O_RSP               OUT NOCOPY VARCHAR2
  
  );

PROCEDURE usp_calcular_dmenos_unidades (

  I_Anyo                IN Estadistico.N_Anyo%Type,
  O_Dia_Menos           OUT NOCOPY Estadistico.N_Dia_Menos%Type,
  O_Dia_Menos_Unidades  OUT NOCOPY Estadistico.I_Dia_Menos_Unidades%Type,
  O_RSP                 OUT NOCOPY VARCHAR2
  
  );

PROCEDURE usp_calcular_beneficio_ciudad (

  I_Anyo          IN Estadistico.N_Anyo%Type,
  O_Ciudad        OUT NOCOPY Estadistico.I_Ciudad%Type,
  O_BNeto_Ciudad  OUT NOCOPY Estadistico.N_BNeto_Ciudad%Type,
  O_RSP           OUT NOCOPY VARCHAR2
  
  );
  
PROCEDURE usp_calcular_porcentaje (

  I_Anyo          IN Estadistico.N_Anyo%Type,
  O_PB_Virtuales  OUT NOCOPY Estadistico.N_PB_Virtuales%Type,
  O_RSP           OUT NOCOPY VARCHAR2
  
  );

PROCEDURE usp_actualizar_historico (

  I_Anyo IN Estadistico.N_Anyo%Type

);
  
END PK_HISTORICOS;

/

CREATE OR REPLACE PACKAGE BODY UOC.PK_HISTORICOS AS

/****************************************************************************************************************************************
*                                                                                                                                       * 
* Nombre........: usp_calcular_beneficio_cadena                                                                                         *
* Descripcin...: Obtiene el beneficio neto de toda la cadena.                                                                          *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Anyo         (Ao a calcular             ) - NUMBER(4)                                                     *
*                 OUTPUT.: O_BNeto_Cadena (Beneficio neto de la cadena) - NUMBER                                                        *
*                          O_RSP          (Resultado de la ejecucin  ) - VARCHAR2                                                      *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_calcular_beneficio_cadena (

  I_Anyo           IN Estadistico.N_Anyo%Type,
  O_BNeto_Cadena   OUT NOCOPY Estadistico.N_Bneto_Cadena%Type,
  O_RSP            OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento      VARCHAR2(50 CHAR);
  Parametros_entrada VARCHAR2(1000 CHAR);
  
  Err_Codigo         NUMBER;
  Err_Descripcion    VARCHAR2(200 CHAR);

BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_HISTORICOS.usp_calcular_beneficio_cadena';
  Parametros_entrada  := '(' || I_Anyo || ')';
  O_RSP               := 'OK';
  
  -- Obtiene el calculo solicitado
  
  SELECT SUM(N_BENEFICIO_NETO) INTO O_BNeto_Cadena
  FROM   HECHO H, TIEMPO T
  WHERE  H.I_TIEMPO = T.I_TIEMPO
  AND    T.N_ANYO = NVL(I_Anyo, T.N_ANYO);
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
   
  EXCEPTION

    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_calcular_beneficio_cadena;

/****************************************************************************************************************************************
*                                                                                                                                       * 
* Nombre........: usp_calcular_beneficio_tienda                                                                                         *
* Descripcin...: Obtiene el identificador de la tienda que ms beneficio neto obtiene, as como la cifra de dicho beneficio.           *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Anyo         (Ao a calcular             ) - NUMBER(4)                                                     *
*                 OUTPUT.: O_Tienda       (Identificador de la tienda ) - INTEGER                                                       *
*                          O_BNeto_Tienda (Beneficio neto de la cadena) - NUMBER                                                        *
*                          O_RSP          (Resultado de la ejecucin  ) - VARCHAR2                                                      *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_calcular_beneficio_tienda (

  I_Anyo           IN Estadistico.N_Anyo%Type,
  O_Tienda         OUT NOCOPY Estadistico.I_Tienda%Type,
  O_BNeto_Tienda   OUT NOCOPY Estadistico.N_Bneto_Tienda%Type,
  O_RSP            OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento      VARCHAR2(50 CHAR);
  Parametros_entrada VARCHAR2(1000 CHAR);
  
  Err_Codigo         NUMBER;
  Err_Descripcion    VARCHAR2(200 CHAR);

BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_HISTORICOS.usp_calcular_beneficio_tienda';
  Parametros_entrada  := '(' || I_Anyo || ')';
  O_RSP               := 'OK';
  
  -- Obtiene el calculo solicitado
  
  SELECT * INTO O_Tienda, O_BNeto_Tienda FROM 
    (SELECT I_TIENDA TIENDA, SUM(N_BENEFICIO_NETO) BENEFICIO_NETO
     FROM HECHO H, TIEMPO T
     WHERE H.I_TIEMPO = T.I_TIEMPO
     AND T.N_ANYO = NVL(I_Anyo, T.N_ANYO)
     GROUP BY I_TIENDA
     ORDER BY BENEFICIO_NETO DESC)
  WHERE ROWNUM <= 1;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
   
  EXCEPTION

    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_calcular_beneficio_tienda;

/****************************************************************************************************************************************
*                                                                                                                                       * 
* Nombre........: usp_calcular_producto_unidades                                                                                        *
* Descripcin...: Obtiene el identificador del producto ms vendido, as como el nmero de unidades del mismo.                          *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Anyo              (Ao a calcular             ) - NUMBER(4)                                                *
*                 OUTPUT.: O_Producto          (Identificador del producto ) - NUMBER(13)                                               *
*                          O_Producto_Unidades (Nmero de unidades vendidas) - INTEGER                                                  *
*                          O_RSP               (Resultado de la ejecucin  ) - VARCHAR2                                                 *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_calcular_producto_unidades (

  I_Anyo               IN Estadistico.N_Anyo%Type,
  O_Producto           OUT NOCOPY Estadistico.N_Producto%Type,
  O_Producto_Unidades  OUT NOCOPY Estadistico.I_Producto_Unidades%Type,
  O_RSP                OUT NOCOPY VARCHAR2
  
  )

IS

  Procedimiento      VARCHAR2(50 CHAR);
  Parametros_entrada VARCHAR2(1000 CHAR);
  
  Err_Codigo         NUMBER;
  Err_Descripcion    VARCHAR2(200 CHAR);

BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_HISTORICOS.usp_calcular_producto_unidades';
  Parametros_entrada  := '(' || I_Anyo || ')';
  O_RSP               := 'OK';
  
  -- Obtiene el calculo solicitado
  
  SELECT * INTO O_Producto, O_Producto_Unidades FROM 
    (SELECT N_PRODUCTO PRODUCTO, SUM(I_CANTIDAD_VENTAS) CANTIDAD_VENDIDA
     FROM HECHO H, TIEMPO T
     WHERE H.I_TIEMPO = T.I_TIEMPO
     AND T.N_ANYO = NVL(I_Anyo, T.N_ANYO)
     GROUP BY N_PRODUCTO
     ORDER BY CANTIDAD_VENDIDA DESC)
  WHERE ROWNUM <= 1;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
   
  EXCEPTION

    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_calcular_producto_unidades;

/****************************************************************************************************************************************
*                                                                                                                                       * 
* Nombre........: usp_calcular_hmas_unidades                                                                                            *
* Descripcin...: Obtiene la hora del da donde ms productos se han vendido, as como el nmero de unidades del mismo.                 *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Anyo              (Ao a calcular             ) - NUMBER(4)                                                *
*                 OUTPUT.: O_Hora_Mas          (Hora del da               ) - NUMBER(2)                                                *
*                          O_Hora_Mas_Unidades (Nmero de unidades vendidas) - INTEGER                                                  *
*                          O_RSP               (Resultado de la ejecucin  ) - VARCHAR2                                                 *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_calcular_hmas_unidades (

  I_Anyo               IN Estadistico.N_Anyo%Type,
  O_Hora_Mas           OUT NOCOPY Estadistico.N_Hora_Mas%Type,
  O_Hora_Mas_Unidades  OUT NOCOPY Estadistico.I_Hora_Mas_Unidades%Type,
  O_RSP                OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento      VARCHAR2(50 CHAR);
  Parametros_entrada VARCHAR2(1000 CHAR);
  
  Err_Codigo         NUMBER;
  Err_Descripcion    VARCHAR2(200 CHAR);

BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_HISTORICOS.usp_calcular_hmas_unidades';
  Parametros_entrada  := '(' || I_Anyo || ')';
  O_RSP               := 'OK';
  
  -- Obtiene el calculo solicitado

  SELECT * INTO O_Hora_Mas, O_Hora_Mas_Unidades FROM 
    (SELECT N_HORA HORA, SUM(I_CANTIDAD_VENTAS) CANTIDAD_VENDIDA
     FROM HECHO H, TIEMPO T
     WHERE H.I_TIEMPO = T.I_TIEMPO
     AND T.N_ANYO = NVL(I_Anyo, T.N_ANYO)
     GROUP BY N_HORA
     ORDER BY CANTIDAD_VENDIDA DESC)
  WHERE ROWNUM <= 1;  
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
   
  EXCEPTION

    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_calcular_hmas_unidades;

/****************************************************************************************************************************************
*                                                                                                                                       * 
* Nombre........: usp_calcular_hmenos_unidades                                                                                          *
* Descripcin...: Obtiene la hora del da donde menos productos se han vendido, as como el nmero de unidades del mismo.               *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Anyo                (Ao a calcular             ) - NUMBER(4)                                              *
*                 OUTPUT.: O_Hora_Menos          (Hora del da               ) - NUMBER(2)                                              *
*                          O_Hora_Menos_Unidades (Nmero de unidades vendidas) - INTEGER                                                *
*                          O_RSP                 (Resultado de la ejecucin  ) - VARCHAR2                                               *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_calcular_hmenos_unidades (

  I_Anyo                 IN Estadistico.N_Anyo%Type,
  O_Hora_Menos           OUT NOCOPY Estadistico.N_Hora_Menos%Type,
  O_Hora_Menos_Unidades  OUT NOCOPY Estadistico.I_Hora_Menos_Unidades%Type,
  O_RSP                  OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento      VARCHAR2(50 CHAR);
  Parametros_entrada VARCHAR2(1000 CHAR);
  
  Err_Codigo         NUMBER;
  Err_Descripcion    VARCHAR2(200 CHAR);

BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_HISTORICOS.usp_calcular_hmenos_unidades';
  Parametros_entrada  := '(' || I_Anyo || ')';
  O_RSP               := 'OK';
  
  -- Obtiene el calculo solicitado

  SELECT * INTO O_Hora_Menos, O_Hora_Menos_Unidades FROM 
    (SELECT N_HORA HORA, SUM(I_CANTIDAD_VENTAS) CANTIDAD_VENDIDA
     FROM HECHO H, TIEMPO T
     WHERE H.I_TIEMPO = T.I_TIEMPO
     AND T.N_ANYO = NVL(I_Anyo, T.N_ANYO)
     GROUP BY N_HORA
     ORDER BY CANTIDAD_VENDIDA ASC)
  WHERE ROWNUM <= 1;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
   
  EXCEPTION

    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_calcular_hmenos_unidades;

/****************************************************************************************************************************************
*                                                                                                                                       * 
* Nombre........: usp_calcular_dmas_unidades                                                                                            *
* Descripcin...: Obtiene el da donde ms productos se han vendido, as como el nmero de unidades del mismo.                          *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Anyo             (Ao a calcular             ) - NUMBER(4)                                                 *
*                 OUTPUT.: O_Dia_Mas          (Da                        ) - NUMBER(2)                                                 *
*                          O_Dia_Mas_Unidades (Nmero de unidades vendidas) - INTEGER                                                   *
*                          O_RSP              (Resultado de la ejecucin  ) - VARCHAR2                                                  *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_calcular_dmas_unidades (

  I_Anyo              IN Estadistico.N_Anyo%Type,
  O_Dia_Mas           OUT NOCOPY Estadistico.N_Dia_Mas%Type,
  O_Dia_Mas_Unidades  OUT NOCOPY Estadistico.I_Dia_Mas_Unidades%Type,
  O_RSP               OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento      VARCHAR2(50 CHAR);
  Parametros_entrada VARCHAR2(1000 CHAR);
  
  Err_Codigo         NUMBER;
  Err_Descripcion    VARCHAR2(200 CHAR);

BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_HISTORICOS.usp_calcular_dmas_unidades';
  Parametros_entrada  := '(' || I_Anyo || ')';
  O_RSP               := 'OK';
  
  -- Obtiene el calculo solicitado

  SELECT * INTO O_Dia_Mas, O_Dia_Mas_Unidades FROM 
    (SELECT T.N_DIA DIA, SUM(I_CANTIDAD_VENTAS) CANTIDAD_VENDIDA
     FROM HECHO H, TIEMPO T
     WHERE H.I_TIEMPO = T.I_TIEMPO
     AND T.N_ANYO = NVL(I_Anyo, T.N_ANYO)
     GROUP BY T.N_DIA
     ORDER BY CANTIDAD_VENDIDA DESC)
  WHERE ROWNUM <= 1;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
   
  EXCEPTION

    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_calcular_dmas_unidades;

/****************************************************************************************************************************************
*                                                                                                                                       * 
* Nombre........: usp_calcular_dmenos_unidades                                                                                          *
* Descripcin...: Obtiene el da donde menos productos se han vendido, as como el nmero de unidades del mismo.                        *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Anyo               (Ao a calcular             ) - NUMBER(4)                                               *
*                 OUTPUT.: O_Dia_Menos          (Da                        ) - NUMBER(2)                                               *
*                          O_Dia_Menos_Unidades (Nmero de unidades vendidas) - INTEGER                                                 *
*                          O_RSP                (Resultado de la ejecucin  ) - VARCHAR2                                                *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_calcular_dmenos_unidades (

  I_Anyo                IN Estadistico.N_Anyo%Type,
  O_Dia_Menos           OUT NOCOPY Estadistico.N_Dia_Menos%Type,
  O_Dia_Menos_Unidades  OUT NOCOPY Estadistico.I_Dia_Menos_Unidades%Type,
  O_RSP                 OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento      VARCHAR2(50 CHAR);
  Parametros_entrada VARCHAR2(1000 CHAR);
  
  Err_Codigo         NUMBER;
  Err_Descripcion    VARCHAR2(200 CHAR);

BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_HISTORICOS.usp_calcular_dmenos_unidades';
  Parametros_entrada  := '(' || I_Anyo || ')';
  O_RSP               := 'OK';
  
  -- Obtiene el calculo solicitado

  SELECT * INTO O_Dia_Menos, O_Dia_Menos_Unidades FROM 
    (SELECT T.N_DIA DIA, SUM(I_CANTIDAD_VENTAS) CANTIDAD_VENDIDA
     FROM HECHO H, TIEMPO T
     WHERE H.I_TIEMPO = T.I_TIEMPO
     AND T.N_ANYO = NVL(I_Anyo, T.N_ANYO)
     GROUP BY T.N_DIA
     ORDER BY CANTIDAD_VENDIDA ASC)
  WHERE ROWNUM <= 1;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
   
  EXCEPTION

    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_calcular_dmenos_unidades;

/****************************************************************************************************************************************
*                                                                                                                                       * 
* Nombre........: usp_calcular_beneficio_ciudad                                                                                         *
* Descripcin...: Obtiene la ciudad que ms beneficio obtuvo, as como la cantidad de dicho beneficio.                                  *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Anyo         (Ao a calcular             ) - NUMBER(4)                                                     *
*                 OUTPUT.: O_Ciudad       (Ciudad con mayor beneficio ) - INTEGER                                                       *
*                          O_BNeto_Ciudad (Beneficio neto de la ciudad) - NUMBER                                                        *
*                          O_RSP          (Resultado de la ejecucin  ) - VARCHAR2                                                      *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_calcular_beneficio_ciudad (

  I_Anyo          IN Estadistico.N_Anyo%Type,
  O_Ciudad        OUT NOCOPY Estadistico.I_Ciudad%Type,
  O_BNeto_Ciudad  OUT NOCOPY Estadistico.N_BNeto_Ciudad%Type,
  O_RSP           OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento      VARCHAR2(50 CHAR);
  Parametros_entrada VARCHAR2(1000 CHAR);
  
  Err_Codigo         NUMBER;
  Err_Descripcion    VARCHAR2(200 CHAR);

BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_HISTORICOS.usp_calcular_beneficio_ciudad';
  Parametros_entrada  := '(' || I_Anyo || ')';
  O_RSP               := 'OK';
  
  -- Obtiene el calculo solicitado

  SELECT * INTO O_Ciudad, O_BNeto_Ciudad FROM 
    (SELECT T.I_CIUDAD CIUDAD, SUM(N_BENEFICIO_NETO) BENEFICIO_NETO
     FROM  TIENDA T, HECHO H, TIEMPO TI
     WHERE T.I_TIENDA = H.I_TIENDA
     AND   H.I_TIEMPO = TI.I_TIEMPO
     AND   TI.N_ANYO = NVL(I_Anyo, TI.N_ANYO)
     GROUP BY T.I_CIUDAD
     ORDER BY BENEFICIO_NETO DESC)
  WHERE ROWNUM <= 1;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
   
  EXCEPTION

    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_calcular_beneficio_ciudad;

/****************************************************************************************************************************************
*                                                                                                                                       * 
* Nombre........: usp_calcular_porcentaje                                                                                               *
* Descripcin...: Obtiene el porcentaje del beneficio de las tiendas virtuales con respecto al total de la cadena.                      *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Anyo         (Ao a calcular                              ) - NUMBER(4)                                    *
*                 OUTPUT.: O_PB_Virtuales (Porcentaje asociado a las tiendas virtuales ) - NUMBER                                       *
*                          O_RSP          (Resultado de la ejecucin                   ) - VARCHAR2                                     *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_calcular_porcentaje (

  I_Anyo          IN Estadistico.N_Anyo%Type,
  O_PB_Virtuales  OUT NOCOPY Estadistico.N_PB_Virtuales%Type,
  O_RSP           OUT NOCOPY VARCHAR2

  )

IS

  Procedimiento      VARCHAR2(50 CHAR);
  Parametros_entrada VARCHAR2(1000 CHAR);
  
  O_BNeto_Cadena     NUMBER;
  
  Err_Codigo         NUMBER;
  Err_Descripcion    VARCHAR2(200 CHAR);

BEGIN
	
  -- Inicializacin de variables
  
  Procedimiento       := 'PK_HISTORICOS.usp_calcular_porcentaje';
  Parametros_entrada  := '(' || I_Anyo || ')';
  O_RSP               := 'OK';

    
  -- Obtiene el calculo solicitado

  SELECT SUM(N_BENEFICIO_NETO) INTO O_PB_Virtuales
  FROM   TIENDA T, HECHO H, TIEMPO TI
  WHERE  T.I_TIENDA = H.I_TIENDA 
  AND    H.I_TIEMPO = TI.I_TIEMPO
  AND    TI.N_ANYO = NVL(I_Anyo, TI.N_ANYO)
  AND    T.V_VIRTUAL = 'S';
  
  IF (O_PB_VIRTUALES IS NULL) THEN
	O_PB_VIRTUALES := 0;
  ELSE
    PK_HISTORICOS.usp_calcular_beneficio_cadena(I_Anyo, O_BNeto_Cadena, O_RSP);
    O_PB_VIRTUALES := (O_PB_VIRTUALES * 100) / O_BNeto_Cadena;
  END IF;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
   
  EXCEPTION

    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_calcular_porcentaje;

/****************************************************************************************************************************************
*                                                                                                                                       * 
* Nombre........: usp_actualizar_historico                                                                                              *
* Descripcin...: Actualiza la informacin histrica.                                                                                   *
*                                                                                                                                       *
* Parmetros....: INPUT..: I_Anyo (Ao a calcular) - NUMBER(4)                                                                          *
*                                                                                                                                       *
*****************************************************************************************************************************************/

PROCEDURE usp_actualizar_historico (

  I_Anyo          IN Estadistico.N_Anyo%Type

  )

IS

  Procedimiento      VARCHAR2(50 CHAR);
  Parametros_entrada VARCHAR2(1000 CHAR);
  
  O_RSP              VARCHAR2(250 CHAR);
  Registros          NUMBER;
  
  O_BNeto_Cadena        Estadistico.N_Bneto_Cadena%Type;
  O_Tienda              Estadistico.I_Tienda%Type;
  O_BNeto_Tienda        Estadistico.N_Bneto_Tienda%Type;
  O_Producto            Estadistico.N_Producto%Type;
  O_Producto_Unidades   Estadistico.I_Producto_Unidades%Type;
  O_Hora_Mas            Estadistico.N_Hora_Mas%Type;
  O_Hora_Mas_Unidades   Estadistico.I_Hora_Mas_Unidades%Type;
  O_Hora_Menos          Estadistico.N_Hora_Menos%Type;
  O_Hora_Menos_Unidades Estadistico.I_Hora_Menos_Unidades%Type;
  O_Dia_Mas             Estadistico.N_Dia_Mas%Type;
  O_Dia_Mas_Unidades    Estadistico.I_Dia_Mas_Unidades%Type;
  O_Dia_Menos           Estadistico.N_Dia_Menos%Type;
  O_Dia_Menos_Unidades  Estadistico.I_Dia_Menos_Unidades%Type;
  O_Ciudad              Estadistico.I_Ciudad%Type;
  O_BNeto_Ciudad        Estadistico.N_BNeto_Ciudad%Type;
  O_PB_Virtuales        Estadistico.N_PB_Virtuales%Type;

  Err_Codigo         NUMBER;
  Err_Descripcion    VARCHAR2(200 CHAR);

BEGIN

  -- Inicializacin de variables
  
  Procedimiento       := 'PK_HISTORICOS.usp_actualizar_historico';
  Parametros_entrada  := '(' || I_Anyo || ')';
  O_RSP               := 'OK';

  -- Obtiene los valores a registrar para el ao indicado

  PK_HISTORICOS.usp_calcular_beneficio_cadena(I_Anyo, O_BNeto_Cadena, O_RSP);  

  IF (O_RSP = 'OK') THEN
  
	PK_HISTORICOS.usp_calcular_beneficio_tienda(I_Anyo, O_Tienda, O_BNeto_Tienda, O_RSP);  
 
  END IF;
  
  IF (O_RSP = 'OK') THEN
  
	PK_HISTORICOS.usp_calcular_producto_unidades(I_Anyo, O_Producto, O_Producto_Unidades, O_RSP);  
 
  END IF;
  
  IF (O_RSP = 'OK') THEN
  
	PK_HISTORICOS.usp_calcular_hmas_unidades(I_Anyo, O_Hora_Mas, O_Hora_Mas_Unidades, O_RSP);  
 
  END IF;
  
  IF (O_RSP = 'OK') THEN
  
	PK_HISTORICOS.usp_calcular_hmenos_unidades(I_Anyo, O_Hora_Menos, O_Hora_Menos_Unidades, O_RSP);  
 
  END IF;
  
  IF (O_RSP = 'OK') THEN
  
	PK_HISTORICOS.usp_calcular_dmas_unidades(I_Anyo, O_Dia_Mas, O_Dia_Mas_Unidades, O_RSP);  
 
  END IF;
  
  IF (O_RSP = 'OK') THEN
  
	PK_HISTORICOS.usp_calcular_dmenos_unidades(I_Anyo, O_Dia_Menos, O_Dia_Menos_Unidades, O_RSP);  
 
  END IF;
  
  IF (O_RSP = 'OK') THEN
  
	PK_HISTORICOS.usp_calcular_beneficio_ciudad(I_Anyo, O_Ciudad, O_BNeto_Ciudad, O_RSP);  
 
  END IF;
  
  IF (O_RSP = 'OK') THEN
  
	PK_HISTORICOS.usp_calcular_porcentaje(I_Anyo, O_PB_Virtuales, O_RSP);  
	
  END IF;
  
  -- Confirma si el ao existe en la tabla

  IF (O_RSP = 'OK') THEN 
  
	SELECT COUNT(*) INTO Registros FROM ESTADISTICO
		WHERE N_ANYO = NVL(I_Anyo, 0);

	IF (Registros = 0) THEN
  
		INSERT INTO ESTADISTICO	 
		  (N_ANYO, N_BNETO_CADENA, I_TIENDA, N_BNETO_TIENDA, N_PRODUCTO, I_PRODUCTO_UNIDADES, N_HORA_MAS, I_HORA_MAS_UNIDADES, N_HORA_MENOS,
		   I_HORA_MENOS_UNIDADES, N_DIA_MAS, I_DIA_MAS_UNIDADES, N_DIA_MENOS, I_DIA_MENOS_UNIDADES, I_CIUDAD, N_BNETO_CIUDAD,
		   N_PB_VIRTUALES, F_ALTA)
		VALUES 
		  (NVL(I_Anyo, 0), O_BNeto_Cadena, O_Tienda, O_BNeto_Tienda, O_Producto, O_Producto_Unidades, O_Hora_Mas, O_Hora_Mas_Unidades, O_Hora_Menos,
		   O_Hora_Menos_Unidades, O_Dia_Mas, O_Dia_Mas_Unidades, O_Dia_Menos, O_Dia_Menos_Unidades, O_Ciudad, O_BNeto_Ciudad, O_PB_Virtuales, SYSTIMESTAMP);
  
	ELSE
        
		UPDATE ESTADISTICO	SET 
		  N_ANYO = NVL(I_Anyo, 0), 
		  N_BNETO_CADENA = O_BNeto_Cadena, 
		  I_TIENDA = O_Tienda, 
		  N_BNETO_TIENDA = O_BNeto_Tienda, 
		  N_PRODUCTO = O_Producto, 
		  I_PRODUCTO_UNIDADES = O_Producto_Unidades, 
		  N_HORA_MAS = O_Hora_Mas, 
		  I_HORA_MAS_UNIDADES = O_Hora_Mas_Unidades, 
		  N_HORA_MENOS = O_Hora_Menos,
		  I_HORA_MENOS_UNIDADES = O_Hora_Menos_Unidades, 
		  N_DIA_MAS = O_Dia_Mas, 
		  I_DIA_MAS_UNIDADES = O_Dia_Mas_Unidades, 
		  N_DIA_MENOS = O_Dia_Menos, 
		  I_DIA_MENOS_UNIDADES = O_Dia_Menos_Unidades, 
		  I_CIUDAD = O_Ciudad, 
		  N_BNETO_CIUDAD = O_BNeto_Ciudad,
		  N_PB_VIRTUALES = O_PB_Virtuales, 
		  F_MODIFICACION = SYSTIMESTAMP
		WHERE N_ANYO = NVL(I_Anyo, 0);
		 	  
	END IF;
  
  END IF;
  
  -- Registra la ejecucin en el log
  
  PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
  
  -- Excepciones 
   
  EXCEPTION

    WHEN OTHERS THEN
      Err_Codigo      := SQLCODE;
      Err_Descripcion := SQLERRM;
      
      O_RSP           := 'ERROR: ' || TO_CHAR(Err_Codigo) 
                                   || '-' 
                                   || Err_Descripcion;
      
      PK_PROCEDIMIENTOS.usp_insertar_log(Procedimiento, Parametros_entrada, O_RSP);
        
END usp_actualizar_historico;

END PK_HISTORICOS;

/

SPOOL OFF;
